@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: ClientPropertyManager.h,v 1.4 2006-10-26 00:48:01 alriddoch Exp $
+// $Id$
 
 #ifndef CLIENT_CLIENT_PROPERTY_MANAGER_H
 #define CLIENT_CLIENT_PROPERTY_MANAGER_H
@@ -28,7 +28,7 @@ class ClientPropertyManager : public PropertyManager {
     ClientPropertyManager();
     virtual ~ClientPropertyManager();
 
-    virtual PropertyBase * addProperty(Entity *, const std::string & name);
+    virtual PropertyBase * addProperty(const std::string & name, int);
 };
 
 #endif // CLIENT_CLIENT_PROPERTY_MANAGER_H
