@@ -15,22 +15,25 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: ecda0b7fbe9eee9eaf310b34f99656138011a153 $
 
 #include "Py_CreatorClient.h"
 
 #include "CreatorClient.h"
 
+#include "rulesets/Python_Script_Utils.h"
 #include "rulesets/Py_Operation.h"
 #include "rulesets/Py_RootEntity.h"
 #include "rulesets/Py_WorldTime.h"
 #include "rulesets/Py_Point3D.h"
 #include "rulesets/Py_Location.h"
-#include "rulesets/Py_Object.h"
+#include "rulesets/Py_Message.h"
 #include "rulesets/Py_Thing.h"
 #include "rulesets/Py_Map.h"
 
 #include "common/debug.h"
+#include "common/id.h"
+#include "common/log.h"
 #include "common/TypeNode.h"
 
 using Atlas::Message::Element;
@@ -46,12 +49,11 @@ static PyObject * CreatorClient_as_entity(PyCreatorClient * self, PyObject *)
         return NULL;
     }
 #endif // NDEBUG
-    PyMessageElement * ret = newPyMessageElement();
-    if (ret == NULL) {
-        return NULL;
+    PyMessage * ret = newPyMessage();
+    if (ret != NULL) {
+        ret->m_obj = new Element(MapType());
+        self->m_mind->addToMessage(ret->m_obj->asMap());
     }
-    ret->m_obj = new Element(MapType());
-    self->m_mind->addToMessage(ret->m_obj->asMap());
     return (PyObject *)ret;
 }
 
@@ -73,8 +75,10 @@ static PyObject * CreatorClient_make(PyCreatorClient * self,
         PyErr_SetString(PyExc_RuntimeError, "Entity creation failed");
         return NULL;
     }
-    PyLocatedEntity * ret = newPyLocatedEntity();
-    ret->m_entity = retval;
+    PyEntity * ret = newPyLocatedEntity();
+    if (ret != NULL) {
+        ret->m_entity.l = retval;
+    }
     return (PyObject *)ret;
 }
 
@@ -118,8 +122,10 @@ static PyObject * CreatorClient_look(PyCreatorClient * self, PyObject * py_id)
         PyErr_SetString(PyExc_RuntimeError, "Entity look failed");
         return NULL;
     }
-    PyLocatedEntity * ret = newPyLocatedEntity();
-    ret->m_entity = retval;
+    PyEntity * ret = newPyLocatedEntity();
+    if (ret != NULL) {
+        ret->m_entity.l = retval;
+    }
     return (PyObject *)ret;
 }
 static PyObject * CreatorClient_look_for(PyCreatorClient * self,
@@ -140,8 +146,10 @@ static PyObject * CreatorClient_look_for(PyCreatorClient * self,
         Py_INCREF(Py_None);
         return Py_None;
     }
-    PyLocatedEntity * ret = newPyLocatedEntity();
-    ret->m_entity = retval;
+    PyEntity * ret = newPyLocatedEntity();
+    if (ret != NULL) {
+        ret->m_entity.l = retval;
+    }
     return (PyObject *)ret;
 }
 
@@ -181,14 +189,14 @@ static PyObject * CreatorClient_delete(PyCreatorClient * self, PyObject * py_id)
 }
 
 static PyMethodDef CreatorClient_methods[] = {
-	{"as_entity",      (PyCFunction)CreatorClient_as_entity, METH_NOARGS},
-	{"make",           (PyCFunction)CreatorClient_make,      METH_O},
-	{"set",            (PyCFunction)CreatorClient_set,       METH_VARARGS},
-	{"look",           (PyCFunction)CreatorClient_look,      METH_O},
-	{"look_for",       (PyCFunction)CreatorClient_look_for,  METH_O},
-	{"send",           (PyCFunction)CreatorClient_send,      METH_O},
-	{"delete",         (PyCFunction)CreatorClient_delete,    METH_O},
-	{NULL,          NULL}           /* sentinel */
+        {"as_entity",      (PyCFunction)CreatorClient_as_entity, METH_NOARGS},
+        {"make",           (PyCFunction)CreatorClient_make,      METH_O},
+        {"set",            (PyCFunction)CreatorClient_set,       METH_VARARGS},
+        {"look",           (PyCFunction)CreatorClient_look,      METH_O},
+        {"look_for",       (PyCFunction)CreatorClient_look_for,  METH_O},
+        {"send",           (PyCFunction)CreatorClient_send,      METH_O},
+        {"delete",         (PyCFunction)CreatorClient_delete,    METH_O},
+        {NULL,          NULL}           /* sentinel */
 };
 
 static void CreatorClient_dealloc(PyCreatorClient *self)
@@ -224,18 +232,24 @@ static PyObject * CreatorClient_getattr(PyCreatorClient *self, char *name)
     }
     if (strcmp(name, "map") == 0) {
         PyMap * map = newPyMap();
-        map->m_map = self->m_mind->getMap();
+        if (map != NULL) {
+            map->m_map = self->m_mind->getMap();
+        }
         return (PyObject *)map;
     }
     if (strcmp(name, "location") == 0) {
         PyLocation * loc = newPyLocation();
-        loc->location = &self->m_mind->m_location;
-        loc->owner = self->m_mind;
+        if (loc != NULL) {
+            loc->location = &self->m_mind->m_location;
+            loc->owner = self->m_mind;
+        }
         return (PyObject *)loc;
     }
     if (strcmp(name, "time") == 0) {
         PyWorldTime * worldtime = newPyWorldTime();
-        worldtime->time = self->m_mind->getTime();
+        if (worldtime != NULL) {
+            worldtime->time = self->m_mind->getTime();
+        }
         return (PyObject *)worldtime;
     }
     if (self->CreatorClient_attr != NULL) {
@@ -277,8 +291,8 @@ static int CreatorClient_setattr(PyCreatorClient *self, char *name, PyObject *v)
         //thing->attributes.erase(attr);
         //return 0;
     //}
-    Element obj = PyObject_asMessageElement(v);
-    if (!obj.isNone() && !obj.isMap() && !obj.isList()) {
+    Element obj;
+    if (PyObject_asMessageElement(v, obj) == 0 && !obj.isMap() && !obj.isList()) {
         thing->setAttr(name, obj);
         return 0;
     }
@@ -295,51 +309,81 @@ static int CreatorClient_compare(PyCreatorClient *self, PyCreatorClient *other)
     return (self->m_mind == other->m_mind) ? 0 : 1;
 }
 
+static int CreatorClient_init(PyCreatorClient * self,
+                              PyObject * args, PyObject * kwds)
+{
+    char * id = NULL;
+
+    if (!PyArg_ParseTuple(args, "s", &id)) {
+        return -1;
+    }
+    long intId = integerId(id);
+    if (intId == -1L) {
+        PyErr_SetString(PyExc_TypeError, "CreatorClient() requires string/int ID");
+        return -1;
+    }
+    // self->m_mind = new CreatorClient(id, intId);
+    return 0;
+}
+
 PyTypeObject PyCreatorClient_Type = {
-	PyObject_HEAD_INIT(&PyType_Type)
-	0,					/*ob_size*/
-	"cppCreatorClient",			/*tp_name*/
-	sizeof(PyCreatorClient),		/*tp_basicsize*/
-	0,					/*tp_itemsize*/
-	/* methods */
-	(destructor)CreatorClient_dealloc,	/*tp_dealloc*/
-	0,					/*tp_print*/
-	(getattrfunc)CreatorClient_getattr,	/*tp_getattr*/
-	(setattrfunc)CreatorClient_setattr,	/*tp_setattr*/
-	(cmpfunc)CreatorClient_compare,		/*tp_compare*/
-	0,					/*tp_repr*/
-	0,					/*tp_as_number*/
-	0,					/*tp_as_sequence*/
-	0,					/*tp_as_mapping*/
-	0,					/*tp_hash*/
+        PyObject_HEAD_INIT(&PyType_Type)
+        0,                                      /*ob_size*/
+        "CreatorClient",                     /*tp_name*/
+        sizeof(PyCreatorClient),                /*tp_basicsize*/
+        0,                                      /*tp_itemsize*/
+        /* methods */
+        (destructor)CreatorClient_dealloc,      /*tp_dealloc*/
+        0,                                      /*tp_print*/
+        (getattrfunc)CreatorClient_getattr,     /*tp_getattr*/
+        (setattrfunc)CreatorClient_setattr,     /*tp_setattr*/
+        (cmpfunc)CreatorClient_compare,         /*tp_compare*/
+        0,                                      /*tp_repr*/
+        0,                                      /*tp_as_number*/
+        0,                                      /*tp_as_sequence*/
+        0,                                      /*tp_as_mapping*/
+        0,                                      /*tp_hash*/
+        0,                                      // tp_call
+        0,                                      // tp_str
+        0,                                      // tp_getattro
+        0,                                      // tp_setattro
+        0,                                      // tp_as_buffer
+        Py_TPFLAGS_DEFAULT,                     // tp_flags
+        "CreatorClient objects",                // tp_doc
+        0,                                      // tp_travers
+        0,                                      // tp_clear
+        0,                                      // tp_richcompare
+        0,                                      // tp_weaklistoffset
+        0,                                      // tp_iter
+        0,                                      // tp_iternext
+        0,                                      // tp_methods
+        0,                                      // tp_members
+        0,                                      // tp_getset
+        0,                                      // tp_base
+        0,                                      // tp_dict
+        0,                                      // tp_descr_get
+        0,                                      // tp_descr_set
+        0,                                      // tp_dictoffset
+        (initproc)CreatorClient_init,           // tp_init
+        0,                                      // tp_alloc
+        0,                                      // tp_new
 };
 
 PyCreatorClient * newPyCreatorClient()
 {
-    PyCreatorClient * self;
-    self = PyObject_NEW(PyCreatorClient, &PyCreatorClient_Type);
-    if (self == NULL) {
-        return NULL;
-    }
-    self->CreatorClient_attr = NULL;
-    return self;
+    return (PyCreatorClient *)PyCreatorClient_Type.tp_new(&PyCreatorClient_Type, 0, 0);
 }
 
 int runClientScript(CreatorClient * c, const std::string & package,
                                        const std::string & func)
 {
-    PyObject * package_name = PyString_FromString(package.c_str());
-    PyObject * mod_dict = PyImport_Import(package_name);
-    Py_DECREF(package_name);
-    if (mod_dict == NULL) {
-        std::cerr << "Cld not find python module " << package
-                  << std::endl << std::flush;
-        PyErr_Print();
+    PyObject * module = Get_PyModule(package);
+    if (module == NULL) {
         return -1;
     }
-    PyObject * function = PyObject_GetAttrString(mod_dict,
+    PyObject * function = PyObject_GetAttrString(module,
                                                  (char *)func.c_str());
-    Py_DECREF(mod_dict);
+    Py_DECREF(module);
     if (function == NULL) {
         std::cerr << "Could not find " << func << " function" << std::endl
                   << std::flush;
@@ -353,6 +397,10 @@ int runClientScript(CreatorClient * c, const std::string & package,
         return -1;
     }
     PyCreatorClient * editor = newPyCreatorClient();
+    if (editor == NULL) {
+        Py_DECREF(function);
+        return -1;
+    }
     editor->m_mind = c;
     PyObject * pyob = PyEval_CallFunction(function, "(O)", editor);
 
@@ -368,3 +416,18 @@ int runClientScript(CreatorClient * c, const std::string & package,
     return 0;
 
 }
+
+void extend_client_python_api()
+{
+    PyObject * server = Get_PyModule("server");
+    if (server == 0) {
+        return;
+    }
+
+    PyCreatorClient_Type.tp_new = PyType_GenericNew;
+    if (PyType_Ready(&PyCreatorClient_Type) < 0) {
+        log(CRITICAL, "Python init failed to ready CreatorClient wrapper type");
+        return;
+    }
+    PyModule_AddObject(server, "CreatorClient", (PyObject *)&PyMap_Type);
+}
