@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: e24cbb84f6cd849d8c71426d4cb03039fafc7707 $
 
 #include "Property_impl.h"
 
@@ -122,7 +122,7 @@ void Property<std::string>::add(const std::string & s,
     }
 }
 
-SoftProperty::SoftProperty() : PropertyBase(0)
+SoftProperty::SoftProperty()
 {
 }
 
