@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 74e4dca6886176cc8505629d7f46d637789ee562 $
 
 #ifndef COMMON_PROPERTY_H
 #define COMMON_PROPERTY_H
@@ -23,9 +23,6 @@
 #include <Atlas/Message/Element.h>
 #include <Atlas/Objects/ObjectsFwd.h>
 
-#include <sigc++/trackable.h>
-#include <sigc++/signal.h>
-
 class Entity;
 
 /// \brief Interface for Entity properties
@@ -35,7 +32,7 @@ class PropertyBase {
   protected:
     /// \brief Flags indicating how this Property should be handled
     unsigned int m_flags;
-    explicit PropertyBase(unsigned int);
+    explicit PropertyBase(unsigned int flags = 0);
   public:
     virtual ~PropertyBase();
 
