@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 773f91d294fec6fac88dd2e154fb1a23c7eb5e29 $
 
 #ifndef COMMON_OP_SWITCH_H
 #define COMMON_OP_SWITCH_H
@@ -64,6 +64,9 @@
         case Atlas::Objects::Operation::TOUCH_NO: \
             _prefix ## TouchOperation(_op, _result); \
             break; \
+        case Atlas::Objects::Operation::USE_NO: \
+            _prefix ## UseOperation(_op, _result); \
+            break; \
         case Atlas::Objects::Operation::WIELD_NO: \
             _prefix ## WieldOperation(_op, _result); \
             break; \
