@@ -15,21 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
-
-#include "Add.h"
-#include "Attack.h"
-#include "Eat.h"
-#include "Burn.h"
-#include "Drop.h"
-#include "Nourish.h"
-#include "Pickup.h"
-#include "Setup.h"
-#include "Tick.h"
-#include "Unseen.h"
-#include "Update.h"
-#include "Monitor.h"
-#include "Connect.h"
+// $Id: b34979c94b3e05037b4397115dccbbd30b5a86d4 $
 
 /// \brief Operation classes not defined in the Atlas spec
 ///
@@ -54,5 +40,7 @@ int NOURISH_NO = -1;
 int PICKUP_NO = -1;
 int SETUP_NO = -1;
 int TICK_NO = -1;
+int THOUGHT_NO = -1;
+int GOAL_INFO_NO = -1;
 
 } } }
