@@ -15,10 +15,12 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: DateTime.cpp,v 1.13 2008-04-28 17:26:09 alriddoch Exp $
+// $Id$
 
 #include "DateTime.h"
 
+#include "common/globals.h"
+
 #include <cstdio>
 #include <cstdlib>
 
@@ -29,11 +31,11 @@
 // Acorn 1/3 time hardcoded for now. This means we keep 24 hours per
 // day, and seconds are still the same length. Clocks would still look
 // same too.
-unsigned int DateTime::m_spm = 20; // seconds per minute
-unsigned int DateTime::m_mph = 60; // minutes per hour
-unsigned int DateTime::m_hpd = 24; // hours per day
-unsigned int DateTime::m_dpm = 28; // days per month
-unsigned int DateTime::m_mpy = 12; // months per year
+unsigned int DateTime::m_spm = SPM; // seconds per minute
+unsigned int DateTime::m_mph = MPH; // minutes per hour
+unsigned int DateTime::m_hpd = HPD; // hours per day
+unsigned int DateTime::m_dpm = DPM; // days per month
+unsigned int DateTime::m_mpy = MPY; // months per year
 
 inline void DateTime::set(int t)
 {
@@ -106,7 +108,7 @@ std::string DateTime::asString()
 {
     //Convert date into string
     char buffer[ 100 ];
-    snprintf( buffer, 100, "%4d-%2d-%2d %2d:%2d:%2d", m_year, m_month, m_day, m_hour, m_minute, m_second );
+    snprintf( buffer, 100, "%04d-%02d-%02d %02d:%02d:%02d", m_year, m_month, m_day, m_hour, m_minute, m_second );
     return std::string( buffer );
 }
 
