@@ -15,12 +15,15 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: BBox.cpp,v 1.7 2006-10-26 00:48:06 alriddoch Exp $
+// $Id$
 
 #include "BBox.h"
 
 #include "common/const.h"
 
+#include <wfmath/axisbox.h>
+#include <wfmath/point.h>
+
 WFMath::CoordType boxSquareSize(const BBox & box)
 {
     if (!box.isValid()) {
