@@ -15,12 +15,14 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: BBox.h,v 1.17 2006-10-26 00:48:07 alriddoch Exp $
+// $Id$
 
-#ifndef PHYSICS_BBOX_H
-#define PHYSICS_BBOX_H
+#ifndef PHYSICS_B_BOX_H
+#define PHYSICS_B_BOX_H
 
-#include <wfmath/axisbox.h>
+#include <wfmath/const.h>
+
+#include <cmath>
 
 typedef WFMath::AxisBox<3> BBox;
 
@@ -42,4 +44,4 @@ inline WFMath::CoordType boxBoundingRadius(const BBox & box)
     return sqrtf(boxSquareBoundingRadius(box));
 }
 
-#endif // PHYSICS_BBOX_H
+#endif // PHYSICS_B_BOX_H
