@@ -15,12 +15,12 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Quaternion.h,v 1.14 2006-10-26 00:48:07 alriddoch Exp $
+// $Id$
 
 #ifndef PHYSICS_QUATERNION_H
 #define PHYSICS_QUATERNION_H
 
-#include <wfmath/quaternion.h>
+#include <wfmath/const.h>
 
 typedef WFMath::Quaternion Quaternion;
 
