@@ -15,32 +15,30 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: ActivePropertyFactory_impl.h,v 1.7 2007-12-20 18:47:28 alriddoch Exp $
+// $Id$
 
 #ifndef RULESETS_ACTIVE_PROPERTY_FACTORY_IMPL_H
 #define RULESETS_ACTIVE_PROPERTY_FACTORY_IMPL_H
 
 #include "ActivePropertyFactory.h"
-#include "Entity.h"
+
+#include "HandlerProperty.h"
 
 /// \brief ActivePropertyFactory constructor
 ///
 /// @param class_no Class number of the operation that will trigger this
 /// Property.
 /// @param handler Handler function called when the right operation arrives
-template <class T>
+template <typename T>
 ActivePropertyFactory<T>::ActivePropertyFactory(int class_no, Handler handler)
                         : m_operationClassNo(class_no), m_handler(handler)
 {
 }
 
-template <class T>
-PropertyBase * ActivePropertyFactory<T>::newProperty(Entity * property_owner)
+template <typename T>
+PropertyBase * ActivePropertyFactory<T>::newProperty()
 {
-    // Install operation handler on property_owner
-    property_owner->installHandler(m_operationClassNo, m_handler);
-
-    return new T();
+    return new HandlerProperty<T>(m_operationClassNo, m_handler);
 }
 
 /// \brief MultiActivePropertyFactory constructor
@@ -55,15 +53,9 @@ MultiActivePropertyFactory<T>::MultiActivePropertyFactory(const HandlerMap &
 }
 
 template <class T>
-PropertyBase * MultiActivePropertyFactory<T>::newProperty(Entity * owner)
+PropertyBase * MultiActivePropertyFactory<T>::newProperty()
 {
-    HandlerMap::const_iterator I = m_handlers.begin();
-    HandlerMap::const_iterator Iend = m_handlers.end();
-    for (; I != Iend; ++I) {
-        owner->installHandler(I->first, I->second);
-    }
-
-    return new T();
+    return new T(m_handlers);
 }
 
 #endif // RULESETS_ACTIVE_PROPERTY_FACTORY_IMPL_H
