@@ -15,17 +15,13 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 73efaded9cdd63ff7c94cd6f3cddb1dfcc4c7e79 $
 
 #ifndef RULESETS_AREA_PROPERTY_H
 #define RULESETS_AREA_PROPERTY_H
 
 #include "LineProperty.h"
 
-#include "physics/Vector3D.h"
-
-#include <set>
-
 /// \brief Class to handle Entity terrain property
 /// \ingroup PropertyClasses
 class AreaProperty : public PropertyBase {
@@ -33,7 +29,7 @@ class AreaProperty : public PropertyBase {
     /// \brief Property data for the line that defines the outline of the area
     LineProperty m_line;
   public:
-    explicit AreaProperty(unsigned int flags);
+    explicit AreaProperty();
 
     virtual bool get(Atlas::Message::Element & val) const;
     virtual void set(const Atlas::Message::Element & val);
