@@ -15,16 +15,17 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 67de7e76d85b6ba8ef1ac60f15990ca620338173 $
 
 #include "BaseMind.h"
 
 #include "Script.h"
 
-#include "common/log.h"
+#include "common/custom.h"
 #include "common/debug.h"
-#include "common/op_switch.h"
 #include "common/Inheritance.h"
+#include "common/log.h"
+#include "common/op_switch.h"
 
 #include <Atlas/Objects/SmartPtr.h>
 #include <Atlas/Objects/Operation.h>
@@ -97,6 +98,10 @@ void BaseMind::sightDeleteOperation(const Operation & op, OpVector & res)
         return;
     }
     const Root & obj = args.front();
+    if (!obj.isValid()) {
+        log(ERROR, "Sight Delete with invalid entity");
+        return;
+    }
     const std::string & id = obj->getId();
     if (!id.empty()) {
         m_map.del(obj->getId());
@@ -247,6 +252,21 @@ void BaseMind::DisappearanceOperation(const Operation & op, OpVector & res)
     }
 }
 
+void BaseMind::UnseenOperation(const Operation & op, OpVector & res)
+{
+    const std::vector<Root> & args = op->getArgs();
+    if (args.empty()) {
+        debug( std::cout << " no args!" << std::endl << std::flush;);
+        return;
+    }
+    const Root & arg = args.front();
+    if (arg->isDefaultId()) {
+        log(ERROR, "BaseMind: Unseen op has no arg ID");
+        return;
+    }
+    m_map.del(arg->getId());
+}
+
 void BaseMind::operation(const Operation & op, OpVector & res)
 {
     // This might end up being quite tricky to do
@@ -281,6 +301,9 @@ void BaseMind::operation(const Operation & op, OpVector & res)
             DisappearanceOperation(op, res);
             break;
         default:
+            if (op_no == Atlas::Objects::Operation::UNSEEN_NO) {
+                UnseenOperation(op, res);
+            }
             // ERROR
             break;
     }
