@@ -15,22 +15,18 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: c721fd8824b96920d97f211deb1360ebef6029cc $
 
 #ifndef RULESETS_CALENDAR_PROPERTY_H
 #define RULESETS_CALENDAR_PROPERTY_H
 
 #include "common/Property.h"
 
-#include <set>
-
-typedef std::map<int, std::set<int> > PointSet;
-
 /// \brief Class to handle World calendar property
 /// \ingroup PropertyClasses
 class CalendarProperty : public PropertyBase {
   public:
-    explicit CalendarProperty(unsigned int flags);
+    CalendarProperty();
 
     virtual bool get(Atlas::Message::Element &) const;
     virtual void set(const Atlas::Message::Element &);
