@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: c057c0e2196778c9883bd7a638157755205b1af4 $
 
 #include "Character.h"
 
@@ -26,9 +26,11 @@
 #include "EntityProperty.h"
 #include "OutfitProperty.h"
 #include "StatusProperty.h"
+#include "TasksProperty.h"
 
 #include "common/op_switch.h"
 #include "common/const.h"
+#include "common/custom.h"
 #include "common/debug.h"
 #include "common/globals.h"
 #include "common/log.h"
@@ -264,19 +266,35 @@ Character::~Character()
     }
 }
 
-/// \brief Set a new task as the one being performed by the Character
+/// \brief Set up a new task as the one being performed by the Character
 ///
-/// The old one is cleared and deleted if present
 /// @param task The new task to be assigned to the Character
-void Character::setTask(Task * task)
+/// @param op The operation that initiates the task.
+/// @param res The result of the task startup.
+int Character::startTask(Task * task, const Operation & op, OpVector & res)
 {
+    bool update_required = false;
     if (m_task != 0) {
-        clearTask();
+        update_required = true;
+        m_task->decRef();
     }
     m_task = task;
-    task->incRef();
+    m_task->incRef();
 
-    updateTask();
+    m_task->initTask(op, res);
+
+    if (m_task->obsolete()) {
+        m_task->decRef();
+        m_task = 0;
+    } else {
+        update_required = true;
+    }
+
+    if (update_required) {
+        updateTask();
+    }
+
+    return (m_task == 0) ? -1 : 0;
 }
 
 /// \brief Update the visible representation of the current task
@@ -285,19 +303,16 @@ void Character::setTask(Task * task)
 /// to reflect the current status of the task.
 void Character::updateTask()
 {
-    if (m_task == 0) {
-        log(ERROR, "Character::updateTask called when no task running");
-    }
+    TasksProperty * tp = requirePropertyClass<TasksProperty>(TASKS);
 
-    Anonymous set_arg;
-    m_task->addToEntity(set_arg);
-    set_arg->setId(getId());
+    // Check if this flag is already set. If so, there may be no need
+    // to send the update op.
+    tp->setFlags(flag_unsent);
 
-    Set set;
-    set->setArgs1(set_arg);
-    set->setTo(getId());
-    
-    sendWorld(set);
+    Update update;
+    update->setTo(getId());
+
+    sendWorld(update);
 }
 
 /// \brief Clean up and remove the task currently being executed
@@ -313,15 +328,7 @@ void Character::clearTask()
     m_task->decRef();
     m_task = 0;
 
-    Anonymous set_arg;
-    set_arg->setAttr(TASKS, ListType());
-    set_arg->setId(getId());
-
-    Set set;
-    set->setArgs1(set_arg);
-    set->setTo(getId());
-
-    sendWorld(set);
+    updateTask();
 }
 
 void Character::ImaginaryOperation(const Operation & op, OpVector & res)
@@ -383,6 +390,11 @@ void Character::TickOperation(const Operation & op, OpVector & res)
                 clearTask();
             } else {
                 updateTask();
+                if (res.empty()) {
+                    log(WARNING, String::compose("Character::%1: Task %2 has "
+                                                 "stalled", __func__,
+                                                 m_task->name()));
+                }
             }
         } else if (arg->getName() == "mind") {
             // Do nothing. Passed to mind.
@@ -404,7 +416,7 @@ void Character::TickOperation(const Operation & op, OpVector & res)
 
 void Character::TalkOperation(const Operation & op, OpVector & res)
 {
-    debug( std::cout << "Character::OPeration(Talk)" << std::endl<<std::flush;);
+    debug( std::cout << "Character::Operation(Talk)" << std::endl<<std::flush;);
     Sound s;
     s->setArgs1(op);
     res.push_back(s);
@@ -442,6 +454,207 @@ void Character::NourishOperation(const Operation & op, OpVector & res)
     res.push_back(si);
 }
 
+void Character::UseOperation(const Operation & op, OpVector & res)
+{
+    debug(std::cout << "Got Use op" << std::endl << std::flush;);
+
+    const std::vector<Root> & args = op->getArgs();
+    if (args.empty()) {
+        if (m_task != 0) {
+            if (!m_task->obsolete()) {
+                m_task->irrelevant();
+            }
+            assert(m_task->obsolete());
+            clearTask();
+        }
+        return;
+    }
+
+    // Are we going to modify this really?
+    EntityProperty * rhw = modPropertyClass<EntityProperty>(RIGHT_HAND_WIELD);
+    if (rhw == 0) {
+        error(op, "Character::UseOp No tool wielded.", res, getId());
+        return;
+    }
+
+    Entity * tool = rhw->data().get();
+    if (tool == 0) {
+        error(op, "Character::UseOp No tool wielded.", res, getId());
+        return;
+    }
+    // FIXME Get a tool id from the op attributes?
+
+    Element toolOpAttr;
+    std::set<std::string> toolOps;
+    std::string op_type;
+
+    // Determine the operations this tool supports
+    if (!tool->getAttr("operations", toolOpAttr)) {
+        log(NOTICE, "Character::UseOp Attempt to use something not a tool");
+        return;
+    }
+
+    if (!toolOpAttr.isList()) {
+        log(ERROR, "Character::UseOp Tool has non list operations list");
+        return;
+    }
+    const ListType & toolOpList = toolOpAttr.asList();
+    if (toolOpList.empty()) {
+        log(ERROR, "Character::UseOp Tool operation list is empty");
+        return;
+    }
+    ListType::const_iterator J = toolOpList.begin();
+    ListType::const_iterator Jend = toolOpList.end();
+    assert(J != Jend);
+    if (!(*J).isString()) {
+        log(ERROR, "Character::UseOp Tool operation list is malformed");
+        return;
+    }
+    op_type = (*J).String();
+    debug(std::cout << "default tool op is " << op_type << std::endl
+                                                        << std::flush;);
+    for (; J != Jend; ++J) {
+        if (!(*J).isString()) {
+            log(ERROR, "Character::UseOp Tool has non string in operations list");
+        } else {
+            toolOps.insert((*J).String());
+        }
+    }
+
+
+    RootEntity entity_arg(0);
+
+    assert(!entity_arg.isValid());
+
+    // Look at Use args. If arg is an entity, this is the target.
+    // If arg is an operation, this is the operation to be used, and the
+    // sub op arg may be an entity specifying target. If op to be used is
+    // specified, this is checked against the ops permitted by this tool.
+    const Root & arg = args.front();
+    const std::string & argtype = arg->getObjtype();
+    if (argtype == "op") {
+        if (!arg->hasAttrFlag(Atlas::Objects::PARENTS_FLAG) ||
+            (arg->getParents().empty())) {
+            error(op, "Use arg op has malformed parents", res, getId());
+            return;
+        }
+        op_type = arg->getParents().front();
+        debug(std::cout << "Got op type " << op_type << " from arg"
+                        << std::endl << std::flush;);
+        if (toolOps.find(op_type) == toolOps.end()) {
+            error(op, "Use op is not permitted by tool", res, getId());
+            return;
+        }
+        // Check against valid ops
+        Operation arg_op = smart_dynamic_cast<Operation>(arg);
+        if (!arg_op.isValid()) {
+            error(op, "Use op arg is a malformed op", res, getId());
+            return;
+        }
+
+        const std::vector<Root> & arg_op_args = arg_op->getArgs();
+        if (!arg_op_args.empty()) {
+            entity_arg = smart_dynamic_cast<RootEntity>(arg_op_args.front());
+            if (!entity_arg.isValid()) {
+                error(op, "Use op target is malformed", res, getId());
+                return;
+            }
+        }
+    } else if (argtype == "obj") {
+        entity_arg = smart_dynamic_cast<RootEntity>(arg);
+        if (!entity_arg.isValid()) {
+            error(op, "Use target is malformed", res, getId());
+            return;
+        }
+    } else {
+        error(op, "Use arg has unknown objtype", res, getId());
+        return;
+    }
+
+    Anonymous target;
+    if (!entity_arg.isValid()) {
+        error(op, "Character::UseOperation No target specified", res, getId());
+        return;
+    }
+
+    if (!entity_arg->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
+        error(op, "Character::UseOperation Target entity has no ID", res, getId());
+        return;
+    }
+    target->setId(entity_arg->getId());
+
+    if (entity_arg->hasAttrFlag(Atlas::Objects::Entity::POS_FLAG)) {
+        target->setPos(entity_arg->getPos());
+    }
+
+    if (op_type.empty()) {
+        error(op, "Character::UseOperation Unable to determine op type for tool", res, getId());
+        return;
+    }
+
+    debug(std::cout << "Using tool " << tool->getType() << " on "
+                    << target->getId()
+                    << " with " << op_type << " action."
+                    << std::endl << std::flush;);
+
+    Root obj = Atlas::Objects::Factories::instance()->createObject(op_type);
+    if (!obj.isValid()) {
+        log(ERROR,
+            String::compose("Character::UseOperation Unknown op type "
+                            "\"%1\" requested by \"%2\" tool.",
+                            op_type, tool->getType()));
+        return;
+    }
+    Operation rop = smart_dynamic_cast<Operation>(obj);
+    if (!rop.isValid()) {
+        log(ERROR, String::compose("Character::UseOperation Op type "
+                                   "\"%1\" requested by %2 tool, "
+                                   "but it is not an operation type",
+                                   op_type, tool->getType()));
+        // FIXME Think hard about how this error is reported. Would the error
+        // make it back to the client if we made an error response?
+        return;
+    } else if (!target->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
+        debug(std::cout << "No target" << std::endl << std::flush;);
+    } else {
+        rop->setArgs1(target);
+    }
+
+    rop->setTo(tool->getId());
+
+    Entity * target_ent = BaseWorld::instance().getEntity(entity_arg->getId());
+    if (target_ent == 0) {
+        error(op, "Character::UseOperation Target does not exist", res, getId());
+        return;
+    }
+
+    Task * task = BaseWorld::instance().activateTask(tool->getType()->name(),
+                                                     op_type,
+                                                     target_ent->getType()->name(),
+                                                     *this);
+    if (task != NULL) {
+        assert(res.empty());
+        if (startTask(task, rop, res) == 0 && res.empty()) {
+            // If initialising the task did not result in any operation at all
+            // then the task cannot work correctly. In this case all we can
+            // do is flag an error, and get rid of the task.
+            log(ERROR, String::compose("Character::UseOperation Op type "
+                                       "\"%1\" of tool \"%2\" activated a task,"
+                                       " but it did not initialise",
+                                       op_type, tool->getType()));
+            m_task->irrelevant();
+            clearTask();
+        }
+        return;
+    }
+
+    res.push_back(rop);
+
+    Sight sight;
+    sight->setArgs1(rop);
+    res.push_back(sight);
+}
+
 void Character::WieldOperation(const Operation & op, OpVector & res)
 {
     if (op->getArgs().empty()) {
@@ -571,10 +784,7 @@ void Character::AttackOperation(const Operation & op, OpVector & res)
         return;
     }
 
-    setTask(combat);
-    m_task->initTask(op, res);
-    if (m_task->obsolete()) {
-        clearTask();
+    if (startTask(combat, op, res) != 0) {
         return;
     }
 
@@ -585,10 +795,7 @@ void Character::AttackOperation(const Operation & op, OpVector & res)
         return;
     }
 
-    attacker->setTask(combat);
-    attacker->m_task->initTask(op, res);
-    if (attacker->m_task->obsolete()) {
-        attacker->clearTask();
+    if (attacker->startTask(combat, op, res) != 0) {
         clearTask();
         return;
     }
@@ -600,7 +807,7 @@ void Character::AttackOperation(const Operation & op, OpVector & res)
 /// @param res The filtered result is returned here.
 void Character::mindActuateOperation(const Operation & op, OpVector & res)
 {
-    debug(std::cout << "Got Acuate op from mind" << std::endl << std::flush;);
+    debug(std::cout << "Got Actuate op from mind" << std::endl << std::flush;);
 
     const std::vector<Root> & args = op->getArgs();
     if (args.empty()) {
@@ -784,205 +991,8 @@ void Character::mindSetupOperation(const Operation & op, OpVector & res)
 void Character::mindUseOperation(const Operation & op, OpVector & res)
 {
     debug(std::cout << "Got Use op from mind" << std::endl << std::flush;);
-
-    const std::vector<Root> & args = op->getArgs();
-    if (args.empty()) {
-        if (m_task != 0) {
-            if (!m_task->obsolete()) {
-                m_task->irrelevant();
-            }
-            assert(m_task->obsolete());
-            clearTask();
-        }
-        return;
-    }
-
-    EntityProperty * rhw = modPropertyClass<EntityProperty>(RIGHT_HAND_WIELD);
-    if (rhw == 0) {
-        error(op, "Character::mindUseOp No tool wielded.", res, getId());
-        return;
-    }
-
-    Entity * tool = rhw->data().get();
-    if (tool == 0) {
-        error(op, "Character::mindUseOp No tool wielded.", res, getId());
-        return;
-    }
-    // FIXME Get a tool id from the op attributes?
-
-    Element toolOpAttr;
-    std::set<std::string> toolOps;
-    std::string op_type;
-
-    // Determine the operations this tool supports
-    if (!tool->getAttr("operations", toolOpAttr)) {
-        log(NOTICE, "Character::mindUseOp Attempt to use something not a tool");
-        return;
-    }
-
-    if (!toolOpAttr.isList()) {
-        log(ERROR, "Character::mindUseOp Tool has non list operations list");
-        return;
-    }
-    const ListType & toolOpList = toolOpAttr.asList();
-    if (toolOpList.empty()) {
-        log(ERROR, "Character::mindUseOp Tool operation list is empty");
-        return;
-    }
-    ListType::const_iterator J = toolOpList.begin();
-    ListType::const_iterator Jend = toolOpList.end();
-    assert(J != Jend);
-    if (!(*J).isString()) {
-        log(ERROR, "Character::mindUseOp Tool operation list is malformed");
-        return;
-    }
-    op_type = (*J).String();
-    debug(std::cout << "default tool op is " << op_type << std::endl
-                                                        << std::flush;);
-    for (; J != Jend; ++J) {
-        if (!(*J).isString()) {
-            log(ERROR, "Character::mindUseOp Tool has non string in operations list");
-        } else {
-            toolOps.insert((*J).String());
-        }
-    }
-
-
-    RootEntity entity_arg(0);
-
-    assert(!entity_arg.isValid());
-
-    // Look at Use args. If arg is an entity, this is the target.
-    // If arg is an operation, this is the operation to be used, and the
-    // sub op arg may be an entity specifying target. If op to be used is
-    // specified, this is checked against the ops permitted by this tool.
-    const Root & arg = args.front();
-    const std::string & argtype = arg->getObjtype();
-    if (argtype == "op") {
-        if (!arg->hasAttrFlag(Atlas::Objects::PARENTS_FLAG) ||
-            (arg->getParents().empty())) {
-            error(op, "Use arg op has malformed parents", res, getId());
-            return;
-        }
-        op_type = arg->getParents().front();
-        debug(std::cout << "Got op type " << op_type << " from arg"
-                        << std::endl << std::flush;);
-        if (toolOps.find(op_type) == toolOps.end()) {
-            error(op, "Use op is not permitted by tool", res, getId());
-            return;
-        }
-        // Check against valid ops
-        Operation arg_op = smart_dynamic_cast<Operation>(arg);
-        if (!arg_op.isValid()) {
-            error(op, "Use op arg is a malformed op", res, getId());
-            return;
-        }
-
-        const std::vector<Root> & arg_op_args = arg_op->getArgs();
-        if (!arg_op_args.empty()) {
-            entity_arg = smart_dynamic_cast<RootEntity>(arg_op_args.front());
-            if (!entity_arg.isValid()) {
-                error(op, "Use op target is malformed", res, getId());
-                return;
-            }
-        }
-    } else if (argtype == "obj") {
-        entity_arg = smart_dynamic_cast<RootEntity>(arg);
-        if (!entity_arg.isValid()) {
-            error(op, "Use target is malformed", res, getId());
-            return;
-        }
-    } else {
-        error(op, "Use arg has unknown objtype", res, getId());
-        return;
-    }
-
-    Anonymous target;
-    if (!entity_arg.isValid()) {
-        error(op, "Character::mindUseOperation No target specified", res, getId());
-        return;
-    }
-
-    if (!entity_arg->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
-        error(op, "Character::mindUseOperation Target entity has no ID", res, getId());
-        return;
-    }
-    target->setId(entity_arg->getId());
-
-    if (entity_arg->hasAttrFlag(Atlas::Objects::Entity::POS_FLAG)) {
-        target->setPos(entity_arg->getPos());
-    }
-
-    if (op_type.empty()) {
-        error(op, "Character::mindUseOperation Unable to determine op type for tool", res, getId());
-        return;
-    }
-
-    debug(std::cout << "Using tool " << tool->getType() << " on "
-                    << target->getId()
-                    << " with " << op_type << " action."
-                    << std::endl << std::flush;);
-
-    Root obj = Atlas::Objects::Factories::instance()->createObject(op_type);
-    if (!obj.isValid()) {
-        log(ERROR,
-            String::compose("Character::mindUseOperation Unknown op type "
-                            "\"%1\" requested by \"%2\" tool.",
-                            op_type, tool->getType()));
-        return;
-    }
-    Operation rop = smart_dynamic_cast<Operation>(obj);
-    if (!rop.isValid()) {
-        log(ERROR, String::compose("Character::mindUseOperation Op type "
-                                   "\"%1\" requested by %2 tool, "
-                                   "but it is not an operation type",
-                                   op_type, tool->getType()));
-        // FIXME Think hard about how this error is reported. Would the error
-        // make it back to the client if we made an error response?
-        return;
-    } else if (!target->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
-        debug(std::cout << "No target" << std::endl << std::flush;);
-    } else {
-        rop->setArgs1(target);
-    }
-
-    rop->setTo(tool->getId());
-
-    Entity * target_ent = BaseWorld::instance().getEntity(entity_arg->getId());
-    if (target_ent == 0) {
-        error(op, "Character::mindUseOperation Target does not exist", res, getId());
-        return;
-    }
-
-    Task * task = BaseWorld::instance().activateTask(tool->getType()->name(),
-                                                     op_type,
-                                                     target_ent->getType()->name(),
-                                                     *this);
-    if (task != NULL) {
-        setTask(task);
-        assert(res.empty());
-        m_task->initTask(rop, res);
-        if (m_task->obsolete()) {
-            clearTask();
-        } else if (res.empty()) {
-            // If initialising the task did not result in any operation at all
-            // then the task cannot work correctly. In this case all we can
-            // do is flag an error, and get rid of the task.
-            log(ERROR, String::compose("Character::mindUseOperation Op type "
-                                       "\"%1\" of tool \"%2\" activated a task,"
-                                       " but it did not initialise",
-                                       op_type, tool->getType()));
-            m_task->irrelevant();
-            clearTask();
-        }
-        return;
-    }
-
-    res.push_back(rop);
-
-    Sight sight;
-    sight->setArgs1(rop);
-    res.push_back(sight);
+    op->setTo(getId());
+    res.push_back(op);
 }
 
 /// \brief Filter a Update operation coming from the mind
@@ -1389,6 +1399,16 @@ void Character::mindEatOperation(const Operation & op, OpVector & res)
     res.push_back(op);
 }
 
+/// \brief Filter a GoalInfo operation coming from the mind
+///
+/// @param op The operation to be filtered.
+/// @param res The filtered result is returned here.
+void Character::mindGoalInfoOperation(const Operation & op, OpVector & res)
+{
+    op->setTo(getId());
+    res.push_back(op);
+}
+
 /// \brief Filter a Touch operation coming from the mind
 ///
 /// @param op The operation to be filtered.
@@ -1467,6 +1487,16 @@ bool Character::w2mSetupOperation(const Operation & op)
     return false;
 }
 
+/// \brief Filter a Thought operation coming from the mind
+///
+/// @param op The operation to be filtered.
+/// @param res The filtered result is returned here.
+void Character::mindThoughtOperation(const Operation & op, OpVector & res)
+{
+    op->setTo(getId());
+    res.push_back(op);
+}
+
 /// \brief Filter a Tick operation coming from the world to the mind
 ///
 /// @param op The operation to be filtered.
@@ -1623,6 +1653,10 @@ void Character::mind2body(const Operation & op, OpVector & res)
                 mindTickOperation(op, res);
             } else if (op_no == Atlas::Objects::Operation::UPDATE_NO) {
                 mindUpdateOperation(op, res);
+            } else if (op_no == Atlas::Objects::Operation::THOUGHT_NO) {
+                mindThoughtOperation(op, res);
+            } else if (op_no == Atlas::Objects::Operation::GOAL_INFO_NO) {
+                mindGoalInfoOperation(op, res);
             } else {
                 mindOtherOperation(op, res);
             }
