@@ -15,17 +15,13 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 0f62c198b9ccd593e788e730eac443801d31afcc $
 
 #ifndef RULESETS_CHARACTER_H
 #define RULESETS_CHARACTER_H
 
 #include "Thing.h"
 
-#include "modules/EntityRef.h"
-
-#include <sigc++/connection.h>
-
 class BaseMind;
 class Movement;
 class Task;
@@ -79,8 +75,9 @@ class Character : public Character_parent {
 
     /// \brief Accessor for medium term task
     Task * task() { return m_task; }
+    Task ** monitorTask() { return &m_task; }
 
-    void setTask(Task *);
+    int startTask(Task *, const Operation & op, OpVector &);
     void updateTask();
     void clearTask();
 
@@ -91,6 +88,7 @@ class Character : public Character_parent {
     virtual void TickOperation(const Operation & op, OpVector &);
     virtual void TalkOperation(const Operation & op, OpVector &);
     virtual void NourishOperation(const Operation & op, OpVector &);
+    virtual void UseOperation(const Operation & op, OpVector &);
     virtual void WieldOperation(const Operation & op, OpVector &);
     virtual void AttackOperation(const Operation & op, OpVector &);
 
@@ -101,12 +99,14 @@ class Character : public Character_parent {
     virtual void mindDeleteOperation(const Operation &, OpVector &);
     virtual void mindDivideOperation(const Operation &, OpVector &);
     virtual void mindEatOperation(const Operation &, OpVector &);
+    virtual void mindGoalInfoOperation(const Operation &, OpVector &);
     virtual void mindImaginaryOperation(const Operation &, OpVector &);
     virtual void mindLookOperation(const Operation &, OpVector &);
     virtual void mindMoveOperation(const Operation &, OpVector &);
     virtual void mindSetOperation(const Operation &, OpVector &);
     virtual void mindSetupOperation(const Operation &, OpVector &);
     virtual void mindTalkOperation(const Operation &, OpVector &);
+    virtual void mindThoughtOperation(const Operation &, OpVector &);
     virtual void mindTickOperation(const Operation &, OpVector &);
     virtual void mindTouchOperation(const Operation &, OpVector &);
     virtual void mindUpdateOperation(const Operation &, OpVector &);
