@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Creator.cpp,v 1.82 2008-01-26 17:43:21 alriddoch Exp $
+// $Id$
 
 #include "Creator.h"
 
@@ -41,47 +41,17 @@ using Atlas::Objects::Entity::Anonymous;
 static const bool debug_flag = false;
 
 Creator::Creator(const std::string & id, long intId) :
-         Identified(id, intId),
          Creator_parent(id, intId)
 {
     debug( std::cout << "Creator::Creator" << std::endl << std::flush;);
-}
-
-void Creator::sendExternalMind(const Operation & op, OpVector & res)
-{
-    debug(std::cout << "Creator::sendExternalMind(" << op->getParents().front()
-                    << ")" << std::endl << std::flush;);
-    // Simpified version of Character method sendMind() because local
-    // mind of Creator is irrelevant
-    if (0 != m_externalMind) {
-        debug( std::cout << "Sending to external mind" << std::endl
-                         << std::flush;);
-        m_externalMind->operation(op, res);
-    } else {
-        // If we do not have an external mind, and therefor a connection,
-        // there is no purpose to our existance, so we should die.
-        debug( std::cout << "NOTICE: Creator self destruct"
-                         << std::endl << std::flush;);
-        Delete d;
-        Anonymous del_arg;
-        del_arg->setId(getId());
-        d->setArgs1(del_arg);
-        d->setTo(getId());
-        res.push_back(d);
-    }
+    setFlags(entity_ephem);
 }
 
 void Creator::operation(const Operation & op, OpVector & res)
 {
     debug( std::cout << "Creator::operation" << std::endl << std::flush;);
-    // FIXME Why not just call callOperation() to handle the type switch?
-    // The only real reason is that we avoid passing the Delete op to the
-    // mind, so we return early here. Could check for the Delete op in
-    // sendExternalMind() when the mind is gone, thus getting rid of the
-    // problem.
-    // To switch to using callOperation(), some more op handlers would
-    // need to be implemented, in particular SetupOperation() would need
-    // need to be implemented as below. Some might need to be blocked
+    // FIXME: Switch to using callOperation(), some more op handlers would
+    // need to be implemented. Some might need to be blocked
     // to prevent anyone from messing with us, like SetOperation().
     OpNo op_no = op->getClassNo();
     switch(op_no) {
@@ -96,19 +66,14 @@ void Creator::operation(const Operation & op, OpVector & res)
             break;
         case Atlas::Objects::Operation::DELETE_NO:
             DeleteOperation(op, res);
-            // Prevent Delete op from being sent to mind, so another delete
-            // is not created in response.
-            return;
             break;
         default:
-            if (op_no == Atlas::Objects::Operation::SETUP_NO) {
-                BaseWorld::instance().addPerceptive(this);
-            } else if (op_no == Atlas::Objects::Operation::TICK_NO) {
+            if (op_no == Atlas::Objects::Operation::TICK_NO) {
                 TickOperation(op, res);
             }
             break;
     }
-    sendExternalMind(op, res);
+    sendMind(op, res);
 }
 
 void Creator::externalOperation(const Operation & op)
@@ -126,12 +91,14 @@ void Creator::externalOperation(const Operation & op)
     } else if (op->getTo() == getId() && op->isDefaultFutureSeconds()) {
         debug( std::cout << "Creator handling op " << std::endl << std::flush;);
         OpVector lres;
+        OpVector eres;
         callOperation(op, lres);
         OpVector::const_iterator Iend = lres.end();
         for (OpVector::const_iterator I = lres.begin(); I != Iend; ++I) {
             if (!op->isDefaultSerialno()) {
                 (*I)->setRefno(op->getSerialno());
             }
+            sendMind(*I, eres);
             sendWorld(*I);
             // Don't delete lres as it has gone into World's queue
             // World will deal with it.
@@ -157,7 +124,7 @@ void Creator::externalOperation(const Operation & op)
                 u->setRefno(op->getSerialno());
             }
             OpVector res;
-            sendExternalMind(u, res);
+            sendMind(u, res);
             // We are not interested in anything the external mind might return
         }
     }
@@ -169,7 +136,7 @@ void Creator::mindLookOperation(const Operation & op, OpVector & res)
     // entities by type or by name
     debug(std::cout << "Got look up from prived mind from [" << op->getFrom()
                << "] to [" << op->getTo() << "]" << std::endl << std::flush;);
-    m_perceptive = true;
+    m_flags |= entity_perceptive;
     const std::vector<Root> & args = op->getArgs();
     if (args.empty()) {
         op->setTo(BaseWorld::instance().m_gameWorld.getId());
@@ -189,7 +156,7 @@ void Creator::mindLookOperation(const Operation & op, OpVector & res)
                 if (!op->isDefaultSerialno()) {
                     u->setRefno(op->getSerialno());
                 }
-                sendExternalMind(u, res);
+                sendMind(u, res);
                 return;
             }
         } else if (arg->hasAttrFlag(Atlas::Objects::PARENTS_FLAG)) {
@@ -205,7 +172,7 @@ void Creator::mindLookOperation(const Operation & op, OpVector & res)
                     if (!op->isDefaultSerialno()) {
                         u->setRefno(op->getSerialno());
                     }
-                    sendExternalMind(u, res);
+                    sendMind(u, res);
                     return;
                 }
             }
