@@ -15,14 +15,14 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: LocatedEntity.h,v 1.14 2008-01-28 23:48:32 alriddoch Exp $
+// $Id$
 
 #ifndef RULESETS_LOCATED_ENTITY_H
 #define RULESETS_LOCATED_ENTITY_H
 
 #include "modules/Location.h"
 
-#include "common/Identified.h"
+#include "common/Router.h"
 
 #include <set>
 
@@ -31,6 +31,9 @@ class PropertyBase;
 class Script;
 class TypeNode;
 
+template <typename T>
+class Property;
+
 typedef std::set<LocatedEntity *> LocatedEntitySet;
 typedef std::map<std::string, PropertyBase *> PropertyDict;
 
@@ -44,7 +47,7 @@ typedef std::map<std::string, PropertyBase *> PropertyDict;
 /// which lists other entities which specify their location with reference to
 /// this one. It also provides the script interface for handling operations
 /// in scripts rather than in the C++ code.
-class LocatedEntity : public IdentifiedRouter {
+class LocatedEntity : public Router {
   private:
     static std::set<std::string> m_immutable;
     static const std::set<std::string> & immutables();
@@ -101,6 +104,8 @@ class LocatedEntity : public IdentifiedRouter {
     const int getSeq() const { return m_seq; }
     /// \brief Accessor for entity type property
     const TypeNode * getType() const { return m_type; }
+    /// \brief Accessor for properies
+    const PropertyDict & getProperties() const { return m_properties; }
 
     /// \brief Set the value of the entity type property
     void setType(const TypeNode * t) {
@@ -110,11 +115,15 @@ class LocatedEntity : public IdentifiedRouter {
     virtual bool hasAttr(const std::string & name) const;
     virtual bool getAttr(const std::string & name,
                          Atlas::Message::Element &) const;
+    virtual bool getAttrType(const std::string & name,
+                             Atlas::Message::Element &,
+                             int type) const;
     virtual void setAttr(const std::string & name,
                          const Atlas::Message::Element &);
-    virtual PropertyBase * getProperty(const std::string & name) const;
+    virtual const PropertyBase * getProperty(const std::string & name) const;
 
     virtual void onContainered();
+    virtual void onUpdated();
 
     void setScript(Script * scrpt);
     void makeContainer();
@@ -123,33 +132,25 @@ class LocatedEntity : public IdentifiedRouter {
 
     /// \brief Get a property that is required to of a given type.
     template <class PropertyT>
-    PropertyT * getSpecificProperty(const std::string & name)
+    const PropertyT * getPropertyClass(const std::string & name) const
     {
-        PropertyBase * p = getProperty(name);
+        const PropertyBase * p = getProperty(name);
         if (p != 0) {
-            return dynamic_cast<PropertyT *>(p);
+            return dynamic_cast<const PropertyT *>(p);
         }
         return 0;
     }
 
-    /// \brief Require that a property of a given type is set.
-    template <class PropertyT>
-    PropertyT * requireSpecificProperty(const std::string & name,
-                                        const Atlas::Message::Element & def_val
-                                        = Atlas::Message::Element())
+    /// \brief Get a property that is a generic property of a given type
+    template <typename T>
+    const Property<T> * getPropertyType(const std::string & name) const
     {
-        PropertyBase * p = getProperty(name);
-        PropertyT * sp = 0;
+        const PropertyBase * p = getProperty(name);
         if (p != 0) {
-            sp = dynamic_cast<PropertyT *>(p);
+            return dynamic_cast<const Property<T> *>(p);
         }
-        if (sp == 0) {
-            m_properties[name] = sp = new PropertyT;
-            sp->set(def_val);
-        }
-        return sp;
+        return 0;
     }
-
 };
 
 #endif // RULESETS_LOCATED_ENTITY_H
