@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: ac178b38a36413aa4eefb46e3558d663f8ea9a69 $
 
 #include "Py_Location.h"
 #include "Py_Thing.h"
@@ -23,8 +23,11 @@
 #include "Py_Point3D.h"
 #include "Py_Quaternion.h"
 #include "Py_BBox.h"
+#include "Py_World.h"
+#include "Py_Mind.h"
 
 #include "Entity.h"
+#include "BaseMind.h"
 
 #include <sstream>
 
@@ -37,7 +40,11 @@ static PyObject * Location_copy(PyLocation *self)
     }
 #endif // NDEBUG
     PyLocation * ret = newPyLocation();
-    ret->location = new Location(self->location->m_loc, self->location->pos(), self->location->velocity());
+    if (ret != NULL) {
+        ret->location = new Location(self->location->m_loc,
+                                     self->location->pos(),
+                                     self->location->velocity());
+    }
     return (PyObject *)ret;
 }
 
@@ -51,7 +58,7 @@ static void Location_dealloc(PyLocation *self)
     if (self->owner == 0 && self->location != NULL) {
         delete self->location;
     }
-    PyObject_Free(self);
+    self->ob_type->tp_free((PyObject*)self);
 }
 
 static PyObject * Location_getattr(PyLocation *self, char *name)
@@ -71,22 +78,30 @@ static PyObject * Location_getattr(PyLocation *self, char *name)
     }
     if (strcmp(name, "coordinates") == 0) {
         PyPoint3D * v = newPyPoint3D();
-        v->coords = self->location->pos();
+        if (v != NULL) {
+            v->coords = self->location->pos();
+        }
         return (PyObject *)v;
     }
     if (strcmp(name, "velocity") == 0) {
         PyVector3D * v = newPyVector3D();
-        v->coords = self->location->velocity();
+        if (v != NULL) {
+            v->coords = self->location->velocity();
+        }
         return (PyObject *)v;
     }
     if (strcmp(name, "orientation") == 0) {
         PyQuaternion * v = newPyQuaternion();
-        v->rotation = self->location->orientation();
+        if (v != NULL) {
+            v->rotation = self->location->orientation();
+        }
         return (PyObject *)v;
     }
     if (strcmp(name, "bbox") == 0) {
         PyBBox * b = newPyBBox();
-        b->box = self->location->bBox();
+        if (b != NULL) {
+            b->box = self->location->bBox();
+        }
         return (PyObject *)b;
     }
     return Py_FindMethod(Location_methods, (PyObject *)self, name);
@@ -107,12 +122,12 @@ static int Location_setattr(PyLocation *self, char *name, PyObject *v)
         }
         PyEntity * thing = (PyEntity *)v;
 #ifndef NDEBUG
-        if (thing->m_entity == NULL) {
+        if (thing->m_entity.l == NULL) {
             PyErr_SetString(PyExc_AssertionError, "invalid thing");
             return -1;
         }
 #endif // NDEBUG
-        self->location->m_loc = thing->m_entity;
+        self->location->m_loc = thing->m_entity.l;
         return 0;
     }
     if (strcmp(name, "bbox") == 0 && PyBBox_Check(v)) {
@@ -189,10 +204,88 @@ static PyObject * Location_repr(PyLocation *self)
     return PyString_FromString(r.str().c_str());
 }
 
+static int Location_init(PyLocation * self, PyObject * args, PyObject * kwds)
+{
+    // We need to deal with actual args here
+    PyObject * refO = NULL, * coordsO = NULL;
+    LocatedEntity * ref_ent = NULL;
+    bool decrefO = false;
+    if (!PyArg_ParseTuple(args, "|OO", &refO, &coordsO)) {
+        return -1;
+    }
+    if (refO != NULL) {
+        if (!PyLocatedEntity_Check(refO) &&
+            !PyEntity_Check(refO) &&
+            !PyCharacter_Check(refO) &&
+            !PyWorld_Check(refO) &&
+            !PyMind_Check(refO)) {
+            if (PyObject_HasAttrString(refO, "cppthing")) {
+                refO = PyObject_GetAttrString(refO, "cppthing");
+                decrefO = true;
+            }
+            if (!PyObject_IsInstance(refO, (PyObject *)&PyMind_Type) &&
+                !PyObject_IsInstance(refO, (PyObject *)&PyEntity_Type)) {
+                PyErr_SetString(PyExc_TypeError, "Arg ref required");
+                if (decrefO) { Py_DECREF(refO); }
+                return -1;
+            }
+        }
+        if (coordsO != NULL && !PyPoint3D_Check(coordsO)) {
+            PyErr_SetString(PyExc_TypeError, "Arg coords required");
+            if (decrefO) { Py_DECREF(refO); }
+            return -1;
+        }
+    
+        if (PyWorld_Check(refO)) {
+            ref_ent = &BaseWorld::instance().m_gameWorld;
+        } else if (PyMind_Check(refO)) {
+            PyMind * ref = (PyMind*)refO;
+#ifndef NDEBUG
+            if (ref->m_mind == NULL) {
+                PyErr_SetString(PyExc_AssertionError, "Parent mind is invalid");
+                if (decrefO) { Py_DECREF(refO); }
+                return -1;
+            }
+#endif // NDEBUG
+            ref_ent = ref->m_mind;
+        } else {
+            PyEntity * ref = (PyEntity*)refO;
+#ifndef NDEBUG
+            if (ref->m_entity.l == NULL) {
+                PyErr_SetString(PyExc_AssertionError, "Parent thing is invalid");
+                if (decrefO) { Py_DECREF(refO); }
+                return -1;
+            }
+#endif // NDEBUG
+            ref_ent = ref->m_entity.l;
+        }
+    }
+    if (decrefO) { Py_DECREF(refO); }
+    PyPoint3D * coords = (PyPoint3D*)coordsO;
+    if (coords == NULL) {
+        self->location = new Location(ref_ent);
+    } else {
+        self->location = new Location(ref_ent, coords->coords);
+    }
+    return 0;
+}
+
+static PyObject * Location_new(PyTypeObject * type, PyObject *, PyObject *)
+{
+    // This looks allot like the default implementation, except we call the
+    // in-place constructor.
+    PyLocation * self = (PyLocation *)type->tp_alloc(type, 0);
+    if (self != NULL) {
+        self->location = NULL;
+        self->owner = 0;
+    }
+    return (PyObject *)self;
+}
+
 PyTypeObject PyLocation_Type = {
         PyObject_HEAD_INIT(&PyType_Type)
         0,                              /*ob_size*/
-        "Location",                     /*tp_name*/
+        "atlas.Location",               /*tp_name*/
         sizeof(PyLocation),             /*tp_basicsize*/
         0,                              /*tp_itemsize*/
         /* methods */
@@ -206,16 +299,33 @@ PyTypeObject PyLocation_Type = {
         0,                              /*tp_as_sequence*/
         0,                              /*tp_as_mapping*/
         0,                              /*tp_hash*/
+        0,                              // tp_call
+        0,                              // tp_str
+        0,                              // tp_getattro
+        0,                              // tp_setattro
+        0,                              // tp_as_buffer
+        Py_TPFLAGS_DEFAULT,             // tp_flags
+        "Location objects",             // tp_doc
+        0,                              // tp_travers
+        0,                              // tp_clear
+        0,                              // tp_richcompare
+        0,                              // tp_weaklistoffset
+        0,                              // tp_iter
+        0,                              // tp_iternext
+        0,                              // tp_methods
+        0,                              // tp_members
+        0,                              // tp_getset
+        0,                              // tp_base
+        0,                              // tp_dict
+        0,                              // tp_descr_get
+        0,                              // tp_descr_set
+        0,                              // tp_dictoffset
+        (initproc)Location_init,        // tp_init
+        0,                              // tp_alloc
+        Location_new,                   // tp_new
 };
 
 PyLocation * newPyLocation()
 {
-        PyLocation * self;
-        self = PyObject_NEW(PyLocation, &PyLocation_Type);
-        if (self == NULL) {
-                return NULL;
-        }
-        self->location = NULL;
-        self->owner = 0;
-        return self;
+    return (PyLocation *)PyLocation_Type.tp_new(&PyLocation_Type, 0, 0);
 }
