@@ -15,21 +15,24 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 8d0978030e65b2d0106e7aefc2a1664a9a7e824a $
 
 #include "Py_Map.h"
 #include "Py_Location.h"
 #include "Py_Thing.h"
 #include "Py_Operation.h"
 #include "Py_RootEntity.h"
-#include "Py_Object.h"
+#include "Py_Message.h"
 
 #include "MemEntity.h"
 #include "MemMap.h"
+#include "Script.h"
 
 #include <Atlas/Objects/RootEntity.h>
 #include <Atlas/Objects/objectFactory.h>
 
+using Atlas::Objects::Root;
+using Atlas::Objects::Factories;
 using Atlas::Objects::Entity::RootEntity;
 
 static PyObject * Map_find_by_location(PyMap * self, PyObject * args)
@@ -51,6 +54,10 @@ static PyObject * Map_find_by_location(PyMap * self, PyObject * args)
         return NULL;
     }
     PyLocation * where = (PyLocation *)where_obj;
+    if (!where->location->isValid()) {
+        PyErr_SetString(PyExc_RuntimeError, "Location is incomplete");
+        return NULL;
+    }
     MemEntityVector res = self->m_map->findByLocation(*where->location,
                                                       radius, type);
     PyObject * list = PyList_New(res.size());
@@ -114,27 +121,36 @@ static PyObject * Map_updateAdd(PyMap * self, PyObject * args)
     if (!PyArg_ParseTuple(args, "Od", &arg, &time)) {
         return NULL;
     }
-    if (PyMessageElement_Check(arg)) {
-        PyMessageElement * me = (PyMessageElement*)arg;
-        Atlas::Objects::Root obj = Atlas::Objects::Factories::instance()->createObject(me->m_obj->asMap());
+    if (PyMessage_Check(arg)) {
+        PyMessage * me = (PyMessage*)arg;
+        if (!me->m_obj->isMap()) {
+            PyErr_SetString(PyExc_TypeError, "arg is a Message that is not a map");
+            return NULL;
+        }
+        Root obj(0);
+        try {
+            obj = Factories::instance()->createObject(me->m_obj->Map());
+        }
+        catch (Atlas::Message::WrongTypeException&) {
+            PyErr_SetString(PyExc_TypeError, "arg is a Message that contains malformed attributes");
+            return NULL;
+        }
         RootEntity ent = Atlas::Objects::smart_dynamic_cast<RootEntity>(obj);
         if (!ent.isValid()) {
             PyErr_SetString(PyExc_TypeError, "arg is a Message that does not represent an entity");
             return NULL;
         }
         MemEntity * ret = self->m_map->updateAdd(ent, time);
-        PyObject * thing = wrapEntity(ret);
-        if (thing == NULL) {
+        if (ret == NULL) {
+            PyErr_SetString(PyExc_TypeError, "arg is a Message that does not have an ID");
             return NULL;
         }
+        PyObject * thing = wrapEntity(ret);
         return thing;
     } else if (PyRootEntity_Check(arg)) {
         PyRootEntity * ent = (PyRootEntity*)arg;
         MemEntity * ret = self->m_map->updateAdd(ent->entity, time);
         PyObject * thing = wrapEntity(ret);
-        if (thing == NULL) {
-            return NULL;
-        }
         return thing;
     } else {
         PyErr_SetString(PyExc_TypeError, "arg is not an Atlas Entity or Message");
@@ -180,9 +196,6 @@ static PyObject * Map_get(PyMap * self, PyObject * py_id)
         return Py_None;
     }
     PyObject * thing = wrapEntity(ret);
-    if (thing == NULL) {
-        return NULL;
-    }
     return thing;
 }
 
@@ -202,9 +215,6 @@ static PyObject * Map_get_add(PyMap * self, PyObject * py_id)
     MemEntity * ret = self->m_map->getAdd(id);
     assert(ret != 0);
     PyObject * thing = wrapEntity(ret);
-    if (thing == NULL) {
-        return NULL;
-    }
     return thing;
 }
 
@@ -279,41 +289,58 @@ static PyMethodDef Map_methods[] = {
     {NULL,                  NULL}           // sentinel
 };
 
-static void Map_dealloc(PyMap *self)
+static int Map_init(PyMap * self, PyObject * args, PyObject * kwds)
 {
-    PyObject_Free(self);
+    Script ** s = new Script*;
+    *s = &noScript;
+    self->m_map = new MemMap(*s);
+    return 0;
 }
 
-static PyObject * Map_getattr(PyMap *self, char *name)
-{
-    return Py_FindMethod(Map_methods, (PyObject *)self, name);
-}
-
-PyTypeObject Map_Type = {
-    PyObject_HEAD_INIT(&PyType_Type)
-    0,                              // ob_size
-    "Map",                          // tp_name
-    sizeof(PyMap),                  // tp_basicsize
-    0,                              // tp_itemsize
-    // methods
-    (destructor)Map_dealloc,        // tp_dealloc
-    0,                              // tp_print
-    (getattrfunc)Map_getattr,       // tp_getattr
-    0,                              // tp_setattr
-    0,                              // tp_compare
-    0,                              // tp_repr
-    0,                              // tp_as_number
-    0,                              // tp_as_sequence
-    0,                              // tp_as_mapping
-    0,                              // tp_hash
+PyTypeObject PyMap_Type = {
+        PyObject_HEAD_INIT(&PyType_Type)
+        0,                              // ob_size
+        "Map",                          // tp_name
+        sizeof(PyMap),                  // tp_basicsize
+        0,                              // tp_itemsize
+        // methods
+        0,                              // tp_dealloc
+        0,                              // tp_print
+        0,                              // tp_getattr
+        0,                              // tp_setattr
+        0,                              // tp_compare
+        0,                              // tp_repr
+        0,                              // tp_as_number
+        0,                              // tp_as_sequence
+        0,                              // tp_as_mapping
+        0,                              // tp_hash
+        0,                              // tp_call
+        0,                              // tp_str
+        0,                              // tp_getattro
+        0,                              // tp_setattro
+        0,                              // tp_as_buffer
+        Py_TPFLAGS_DEFAULT,             // tp_flags
+        "Map objects",                  // tp_doc
+        0,                              // tp_travers
+        0,                              // tp_clear
+        0,                              // tp_richcompare
+        0,                              // tp_weaklistoffset
+        0,                              // tp_iter
+        0,                              // tp_iternext
+        Map_methods,                    // tp_methods
+        0,                              // tp_members
+        0,                              // tp_getset
+        0,                              // tp_base
+        0,                              // tp_dict
+        0,                              // tp_descr_get
+        0,                              // tp_descr_set
+        0,                              // tp_dictoffset
+        (initproc)Map_init,             // tp_init
+        0,                              // tp_alloc
+        0,                              // tp_new
 };
 
 PyMap * newPyMap()
 {
-    PyMap * self;
-    self = PyObject_NEW(PyMap, &Map_Type);
-    if (self == NULL) {
-        return NULL;
-    }
-    return self;
+    return (PyMap *)PyMap_Type.tp_new(&PyMap_Type, 0, 0);
 }
