@@ -15,20 +15,23 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 7cdfd894d64f53ef82cb29b7d69a171b3c0e35ec $
 
 #include "Py_Operation.h"
 #include "Py_RootEntity.h"
 #include "Py_Oplist.h"
-#include "Py_Object.h"
+#include "Py_Message.h"
 #include "Py_Thing.h"
 
 #include "common/log.h"
 
+#include <Atlas/Objects/Generic.h>
+
 using Atlas::Message::Element;
 using Atlas::Message::ListType;
 using Atlas::Objects::Root;
 using Atlas::Objects::Operation::RootOperation;
+using Atlas::Objects::Operation::Generic;
 using Atlas::Objects::Entity::RootEntity;
 
 /*
@@ -132,11 +135,15 @@ static PyObject * Operation_setSeconds(PyOperation * self, PyObject * py_secs)
         return NULL;
     }
 #endif // NDEBUG
-    if (!PyFloat_CheckExact(py_secs)) {
-        PyErr_SetString(PyExc_TypeError, "seconds not a float");
+    double seconds;
+    if (PyFloat_CheckExact(py_secs)) {
+        seconds = PyFloat_AsDouble(py_secs);
+    } else if (PyInt_CheckExact(py_secs)) {
+        seconds = PyInt_AsLong(py_secs);
+    } else {
+        PyErr_SetString(PyExc_TypeError, "seconds not a number");
         return NULL;
     }
-    double seconds = PyFloat_AsDouble(py_secs);
     self->operation->setSeconds(seconds);
 
     Py_INCREF(Py_None);
@@ -153,7 +160,7 @@ static PyObject * Operation_setFutureSeconds(PyOperation * self,
         return NULL;
     }
 #endif // NDEBUG
-    double futureseconds = PyFloat_AsDouble(py_fsecs);
+    double futureseconds;
     if (PyFloat_CheckExact(py_fsecs)) {
         futureseconds = PyFloat_AsDouble(py_fsecs);
     } else if (PyInt_CheckExact(py_fsecs)) {
@@ -187,8 +194,8 @@ static PyObject * Operation_setArgs(PyOperation * self, PyObject * args)
     ListType argslist;
     for(int i = 0; i < PyList_Size(args); i++) {
         PyObject * item = PyList_GetItem(args, i);
-        if (PyMessageElement_Check(item)) {
-            argslist.push_back(*((PyMessageElement*)item)->m_obj);
+        if (PyMessage_Check(item)) {
+            argslist.push_back(*((PyMessage*)item)->m_obj);
         } else if (PyOperation_Check(item)) {
             argslist.push_back(((PyOperation*)item)->operation->asMessage());
         } else {
@@ -293,14 +300,16 @@ static PyObject * Operation_getArgs(PyOperation * self)
 
     const std::vector<Root> & args_list = self->operation->getArgs();
     PyObject * args_pylist = PyList_New(args_list.size());
+    if (args_pylist == NULL) {
+        return NULL;
+    }
     int j = 0;
-    PyMessageElement * item;
+    PyMessage * item;
     std::vector<Root>::const_iterator Iend = args_list.end();
     std::vector<Root>::const_iterator I = args_list.begin();
     for (; I != Iend; ++I, ++j) {
-        item = newPyMessageElement();
+        item = newPyMessage();
         if (item == NULL) {
-            PyErr_SetString(PyExc_TypeError,"error creating list");
             Py_DECREF(args_pylist);
             return NULL;
         }
@@ -348,40 +357,41 @@ static PyObject * Operation_seq_item(PyOperation * self, Py_ssize_t item)
         return 0;
     }
 #endif // NDEBUG
-    const std::vector<Root> & args_list = self->operation->getArgs();
-    std::vector<Root>::const_iterator I = args_list.begin();
-    std::vector<Root>::const_iterator Iend = args_list.end();
-    for(int i = 0; i < item && I != Iend; ++i, ++I);
-    if (I == args_list.end()) {
+    const std::vector<Root> & args= self->operation->getArgs();
+    if (item < 0 || item >= (Py_ssize_t)args.size()) {
         PyErr_SetString(PyExc_TypeError,"Operation.[]: Not enought op arguments");
         return 0;
     }
-    const Root & arg = *I;
+    const Root & arg = args[item];
     RootOperation op = Atlas::Objects::smart_dynamic_cast<RootOperation>(arg);
     if (op.isValid()) {
         PyOperation * ret_op = newPyOperation();
-        ret_op->operation = op;
+        if (ret_op != NULL) {
+            ret_op->operation = op;
+        }
         return (PyObject *)ret_op;
     }
     RootEntity ent = Atlas::Objects::smart_dynamic_cast<RootEntity>(arg);
     if (ent.isValid()) {
         PyRootEntity * ret_ent = newPyRootEntity();
-        ret_ent->entity = ent;
+        if (ret_ent != NULL) {
+            ret_ent->entity = ent;
+        }
         return (PyObject *)ret_ent;
     }
     log(WARNING, "Non operation or entity being returned as arg of operation");
-    PyMessageElement * ret = newPyMessageElement();
-    ret->m_obj = new Element(arg->asMessage());
+    PyMessage * ret = newPyMessage();
+    if (ret != NULL) {
+        ret->m_obj = new Element(arg->asMessage());
+    }
     return (PyObject *)ret;
 }
 
 static PyObject * Operation_num_add(PyOperation *self, PyObject *other)
 {
-    fflush(stdout);
 #ifndef NDEBUG
     if (!self->operation.isValid()) {
         PyErr_SetString(PyExc_AssertionError, "NULL Operation in Operation.num_add");
-        fflush(stdout);
         return NULL;
     }
 #endif // NDEBUG
@@ -390,7 +400,6 @@ static PyObject * Operation_num_add(PyOperation *self, PyObject *other)
         PyOplist * res = newPyOplist();
         res->ops = new OpVector();
         res->ops->push_back(self->operation);
-        fflush(stdout);
         return (PyObject*)res;
 #else
         Py_INCREF(self);
@@ -399,17 +408,17 @@ static PyObject * Operation_num_add(PyOperation *self, PyObject *other)
     }
     if (PyOplist_Check(other)) {
         PyOplist * opl = (PyOplist*)other;
+#ifndef NDEBUG
         if (opl->ops == NULL) {
             PyErr_SetString(PyExc_AssertionError, "invalid OpVector");
             return NULL;
         }
+#endif // NDEBUG
         PyOplist * res = newPyOplist();
-        if (res == NULL) {
-            return NULL;
+        if (res != NULL) {
+            res->ops = new OpVector(*opl->ops);
+            res->ops->push_back(self->operation);
         }
-        res->ops = new OpVector(*opl->ops);
-        res->ops->push_back(self->operation);
-        fflush(stdout);
         return (PyObject*)res;
     }
     if (PyOperation_Check(other)) {
@@ -420,16 +429,13 @@ static PyObject * Operation_num_add(PyOperation *self, PyObject *other)
         }
 #endif // NDEBUG
         PyOplist * res = newPyOplist();
-        if (res == NULL) {
-            return NULL;
+        if (res != NULL) {
+            res->ops = new OpVector();
+            res->ops->push_back(op->operation);
+            res->ops->push_back(self->operation);
         }
-        res->ops = new OpVector();
-        res->ops->push_back(op->operation);
-        res->ops->push_back(self->operation);
-        fflush(stdout);
         return (PyObject*)res;
     }
-    fflush(stdout);
     return NULL;
 }
 
@@ -504,7 +510,7 @@ static PySequenceMethods Operation_seq = {
  *
  */
 
-PyMethodDef RootOperation_methods[] = {
+PyMethodDef Operation_methods[] = {
     {"setSerialno",     (PyCFunction)Operation_setSerialno,     METH_O},
     {"setRefno",        (PyCFunction)Operation_setRefno,        METH_O},
     {"setFrom",         (PyCFunction)Operation_setFrom,         METH_O},
@@ -523,7 +529,7 @@ PyMethodDef RootOperation_methods[] = {
     {NULL,          NULL}
 };
 
-PyMethodDef ConstRootOperation_methods[] = {
+PyMethodDef ConstOperation_methods[] = {
     {"getSerialno",     (PyCFunction)Operation_getSerialno,     METH_NOARGS},
     {"getRefno",        (PyCFunction)Operation_getRefno,        METH_NOARGS},
     {"getFrom",         (PyCFunction)Operation_getFrom,         METH_NOARGS},
@@ -543,21 +549,10 @@ PyMethodDef ConstRootOperation_methods[] = {
 static void Operation_dealloc(PyOperation *self)
 {
     self->operation.~RootOperation();
-    PyObject_Free(self);
+    self->ob_type->tp_free((PyObject*)self);
 }
 
-static inline PyObject * findMethod(PyOperation * self, char * name)
-{
-    return Py_FindMethod(RootOperation_methods, (PyObject *)self, name);
-}
-
-static inline PyObject * findMethod(PyConstOperation * self, char * name)
-{
-    return Py_FindMethod(ConstRootOperation_methods, (PyObject *)self, name);
-}
-
-template <typename T>
-static PyObject * getattr(T * self, char * name)
+static PyObject * Operation_getattro(PyOperation * self, PyObject * oname)
 {
 #ifndef NDEBUG
     if (!self->operation.isValid()) {
@@ -565,6 +560,7 @@ static PyObject * getattr(T * self, char * name)
         return NULL;
     }
 #endif // NDEBUG
+    char * name = PyString_AsString(oname);
     if (strcmp(name, "from_") == 0) {
         return PyString_FromString(self->operation->getFrom().c_str());
     } else if (strcmp(name, "to") == 0) {
@@ -577,21 +573,10 @@ static PyObject * getattr(T * self, char * name)
         }
         return PyString_FromString(parents.front().c_str());
     }
-    return findMethod(self, name);
+    return PyObject_GenericGetAttr((PyObject *)self, oname);
 }
 
-static PyObject * Operation_getattr(PyOperation * self, char * name)
-{
-    return getattr(self, name);
-}
-
-static PyObject * ConstOperation_getattr(PyConstOperation * self, char * name)
-{
-    return getattr(self, name);
-}
-
-
-static int Operation_setattr(PyOperation *self, char *name, PyObject *v)
+static int Operation_setattro(PyOperation *self, PyObject * oname, PyObject *v)
 {
 #ifndef NDEBUG
     if (!self->operation.isValid()) {
@@ -599,6 +584,7 @@ static int Operation_setattr(PyOperation *self, char *name, PyObject *v)
         return -1;
     }
 #endif // NDEBUG
+    char * name = PyString_AsString(oname);
     if (strcmp(name, "from_") == 0) {
         PyObject * thing_id = PyObject_GetAttrString(v, "id");
         if (thing_id == NULL || !PyString_Check(thing_id)) {
@@ -629,35 +615,140 @@ static int Operation_setattr(PyOperation *self, char *name, PyObject *v)
     return -1;
 }
 
+static int addToArgs(std::vector<Root> & args, PyObject * arg)
+{
+    if (PyMessage_Check(arg)) {
+        PyMessage * obj = (PyMessage*)arg;
+#ifndef NDEBUG
+        if (obj->m_obj == NULL) {
+            PyErr_SetString(PyExc_AssertionError,"NULL MessageElement in Operation constructor argument");
+            return -1;
+        }
+#endif // NDEBUG
+        const Element & o = *obj->m_obj;
+        if (o.isMap()) {
+            args.push_back(Atlas::Objects::Factories::instance()->createObject(o.asMap()));
+        } else {
+            PyErr_SetString(PyExc_TypeError, "Operation arg is not a map");
+            return -1;
+        }
+    } else if (PyOperation_Check(arg)) {
+        PyOperation * op = (PyOperation*)arg;
+#ifndef NDEBUG
+        if (!op->operation.isValid()) {
+            PyErr_SetString(PyExc_AssertionError,"Invalid operation in Operation constructor argument");
+            return -1;
+        }
+#endif // NDEBUG
+        args.push_back(op->operation);
+    } else if (PyRootEntity_Check(arg)) {
+        PyRootEntity * ent = (PyRootEntity*)arg;
+#ifndef NDEBUG
+        if (!ent->entity.isValid()) {
+            PyErr_SetString(PyExc_AssertionError,"Invalid rootentity in Operation constructor argument");
+            return -1;
+        }
+#endif // NDEBUG
+        args.push_back(ent->entity);
+    } else {
+        PyErr_SetString(PyExc_TypeError, "Operation arg is of unknown type");
+        return -1;
+    }
+    return 0;
+}
+
+static int Operation_init(PyOperation * self, PyObject * args, PyObject * kwds)
+{
+    char * type;
+    PyObject * arg1 = NULL;
+    PyObject * arg2 = NULL;
+    PyObject * arg3 = NULL;
+
+    if (!PyArg_ParseTuple(args, "s|OOO", &type, &arg1, &arg2, &arg3)) {
+        return -1;
+    }
+    Root r = Atlas::Objects::Factories::instance()->createObject(type);
+    self->operation = Atlas::Objects::smart_dynamic_cast<RootOperation>(r);
+    if (!self->operation.isValid()) {
+        // PyErr_SetString(PyExc_TypeError, "Operation() unknown operation type requested");
+        // return -1;
+        self->operation = Generic();
+        self->operation->setParents(std::list<std::string>(1, type));
+    }
+    if (kwds != NULL) {
+        PyObject * from = PyDict_GetItemString(kwds, "from_");
+        if (from != NULL) {
+            PyObject * from_id = 0;
+            if (PyString_Check(from)) {
+                from_id = from;
+                Py_INCREF(from_id);
+            } else if ((from_id = PyObject_GetAttrString(from, "id")) == NULL) {
+                PyErr_SetString(PyExc_TypeError, "from is not a string and has no id");
+                return -1;
+            }
+            if (!PyString_Check(from_id)) {
+                Py_DECREF(from_id);
+                PyErr_SetString(PyExc_TypeError, "id of from is not a string");
+                return -1;
+            }
+            self->operation->setFrom(PyString_AsString(from_id));
+            Py_DECREF(from_id);
+        }
+        PyObject * to = PyDict_GetItemString(kwds, "to");
+        if (to != NULL) {
+            PyObject * to_id = 0;
+            if (PyString_Check(to)) {
+                to_id = to;
+                Py_INCREF(to_id);
+            } else if ((to_id = PyObject_GetAttrString(to, "id")) == NULL) {
+                PyErr_SetString(PyExc_TypeError, "to is not a string and has no id");
+                return -1;
+            }
+            if (!PyString_Check(to_id)) {
+                Py_DECREF(to_id);
+                PyErr_SetString(PyExc_TypeError, "id of to is not a string");
+                return -1;
+            }
+            self->operation->setTo(PyString_AsString(to_id));
+            Py_DECREF(to_id);
+        }
+    }
+    std::vector<Root> & args_list = self->operation->modifyArgs();
+    assert(args_list.empty());
+    if (arg1 != 0 && addToArgs(args_list, arg1) != 0) {
+        return -1;
+    }
+    if (arg2 != 0 && addToArgs(args_list, arg2) != 0) {
+        return -1;
+    }
+    if (arg3 != 0 && addToArgs(args_list, arg3) != 0) {
+        return -1;
+    }
+    return 0;
+}
+
+static PyObject * Operation_new(PyTypeObject * type, PyObject *, PyObject *)
+{
+    // This looks allot like the default implementation, except we call the
+    // in-place constructor.
+    PyOperation * self = (PyOperation *)type->tp_alloc(type, 0);
+    if (self != NULL) {
+        new (&(self->operation)) RootOperation(0);
+    }
+    return (PyObject *)self;
+}
+
+
 PyTypeObject PyOperation_Type = {
         PyObject_HEAD_INIT(&PyType_Type)
         0,                                      // ob_size
-        "Operation",                            // tp_name
+        "atlas.Operation",                      // tp_name
         sizeof(PyOperation),                    // tp_basicsize
         0,                                      // tp_itemsize
         //  methods 
         (destructor)Operation_dealloc,          // tp_dealloc
         0,                                      // tp_print
-        (getattrfunc)Operation_getattr,         // tp_getattr
-        (setattrfunc)Operation_setattr,         // tp_setattr
-        0,                                      // tp_compare
-        0,                                      // tp_repr
-        &Operation_num,                         // tp_as_number
-        &Operation_seq,                         // tp_as_sequence
-        0,                                      // tp_as_mapping
-        0,                                      // tp_hash
-};
-
-PyTypeObject PyConstOperation_Type = {
-        PyObject_HEAD_INIT(&PyType_Type)
-        0,                                      // ob_size
-        "Operation",                            // tp_name
-        sizeof(PyConstOperation),               // tp_basicsize
-        0,                                      // tp_itemsize
-        //  methods 
-        (destructor)Operation_dealloc,          // tp_dealloc
-        0,                                      // tp_print
-        (getattrfunc)ConstOperation_getattr,    // tp_getattr
+        0,                                      // tp_getattr
         0,                                      // tp_setattr
         0,                                      // tp_compare
         0,                                      // tp_repr
@@ -665,6 +756,73 @@ PyTypeObject PyConstOperation_Type = {
         &Operation_seq,                         // tp_as_sequence
         0,                                      // tp_as_mapping
         0,                                      // tp_hash
+        0,                                      // tp_call
+        0,                                      // tp_str
+        (getattrofunc)Operation_getattro,       // tp_getattro
+        (setattrofunc)Operation_setattro,       // tp_setattro
+        0,                                      // tp_as_buffer
+        Py_TPFLAGS_DEFAULT,                     // tp_flags
+        "Operation objects",                    // tp_doc
+        0,                                      // tp_travers
+        0,                                      // tp_clear
+        0,                                      // tp_richcompare
+        0,                                      // tp_weaklistoffset
+        0,                                      // tp_iter
+        0,                                      // tp_iternext
+        Operation_methods,                      // tp_methods
+        0,                                      // tp_members
+        0,                                      // tp_getset
+        0,                                      // tp_base
+        0,                                      // tp_dict
+        0,                                      // tp_descr_get
+        0,                                      // tp_descr_set
+        0,                                      // tp_dictoffset
+        (initproc)Operation_init,               // tp_init
+        0,                                      // tp_alloc
+        Operation_new,                          // tp_new
+};
+
+PyTypeObject PyConstOperation_Type = {
+        PyObject_HEAD_INIT(&PyType_Type)
+        0,                                      // ob_size
+        "atlas.Operation",                      // tp_name
+        sizeof(PyOperation),               // tp_basicsize
+        0,                                      // tp_itemsize
+        //  methods 
+        (destructor)Operation_dealloc,          // tp_dealloc
+        0,                                      // tp_print
+        0,                                      // tp_getattr
+        0,                                      // tp_setattr
+        0,                                      // tp_compare
+        0,                                      // tp_repr
+        &Operation_num,                         // tp_as_number
+        &Operation_seq,                         // tp_as_sequence
+        0,                                      // tp_as_mapping
+        0,                                      // tp_hash
+        0,                                      // tp_call
+        0,                                      // tp_str
+        (getattrofunc)Operation_getattro,       // tp_getattro
+        0,                                      // tp_setattro
+        0,                                      // tp_as_buffer
+        Py_TPFLAGS_DEFAULT,                     // tp_flags
+        "Operation objects",                    // tp_doc
+        0,                                      // tp_travers
+        0,                                      // tp_clear
+        0,                                      // tp_richcompare
+        0,                                      // tp_weaklistoffset
+        0,                                      // tp_iter
+        0,                                      // tp_iternext
+        ConstOperation_methods,                 // tp_methods
+        0,                                      // tp_members
+        0,                                      // tp_getset
+        0,                                      // tp_base
+        0,                                      // tp_dict
+        0,                                      // tp_descr_get
+        0,                                      // tp_descr_set
+        0,                                      // tp_dictoffset
+        (initproc)Operation_init,               // tp_init
+        0,                                      // tp_alloc
+        Operation_new,                          // tp_new
 };
 
 /*
@@ -673,22 +831,10 @@ PyTypeObject PyConstOperation_Type = {
 
 PyOperation * newPyOperation()
 {
-    PyOperation * self;
-    self = PyObject_NEW(PyOperation, &PyOperation_Type);
-    if (self == NULL) {
-        return NULL;
-    }
-    new (&(self->operation)) RootOperation(NULL);
-    return self;
+    return (PyOperation *)PyOperation_Type.tp_new(&PyOperation_Type, 0, 0);
 }
 
-PyConstOperation * newPyConstOperation()
+PyOperation * newPyConstOperation()
 {
-    PyConstOperation * self;
-    self = PyObject_NEW(PyConstOperation, &PyConstOperation_Type);
-    if (self == NULL) {
-        return NULL;
-    }
-    new (&(self->operation)) RootOperation(NULL);
-    return self;
+    return (PyOperation *)PyConstOperation_Type.tp_new(&PyConstOperation_Type, 0, 0);
 }
