@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: de8add6ae43f22045c06485b5e3e72724a09ad45 $
 
 #include "Py_Operation.h"
 #include "Py_Oplist.h"
@@ -55,15 +55,9 @@ static void Oplist_dealloc(PyOplist *self)
     if (self->ops != NULL) {
         delete self->ops;
     }
-    PyObject_Free(self);
+    self->ob_type->tp_free((PyObject*)self);
 }
 
-static PyObject * Oplist_getattr(PyOplist *self, char *name)
-{
-    return Py_FindMethod(Oplist_methods, (PyObject *)self, name);
-}
-
-
 static PyObject * Oplist_num_add(PyOplist *self, PyObject *other)
 {
 #ifndef NDEBUG
@@ -79,13 +73,12 @@ static PyObject * Oplist_num_add(PyOplist *self, PyObject *other)
     if (PyOplist_Check(other)) {
         PyOplist * opl = (PyOplist*)other;
         PyOplist * res = newPyOplist();
-        if (res == NULL) {
-            return NULL;
-        }
-        res->ops = new OpVector(*self->ops);
-        OpVector::const_iterator Iend = opl->ops->end();
-        for (OpVector::const_iterator I = opl->ops->begin(); I != Iend; ++I) {
-            res->ops->push_back(*I);
+        if (res != NULL) {
+            res->ops = new OpVector(*self->ops);
+            OpVector::const_iterator Iend = opl->ops->end();
+            for (OpVector::const_iterator I = opl->ops->begin(); I != Iend; ++I) {
+                res->ops->push_back(*I);
+            }
         }
         return (PyObject*)res;
     }
@@ -97,12 +90,10 @@ static PyObject * Oplist_num_add(PyOplist *self, PyObject *other)
         }
 #endif // NDEBUG
         PyOplist * res = newPyOplist();
-        if (res == NULL) {
-            return NULL;
+        if (res != NULL) {
+            res->ops = new OpVector(*self->ops);
+            res->ops->push_back(op->operation);
         }
-        res->ops = new OpVector(*self->ops);
-        // res->ops->merge(*self->ops);
-        res->ops->push_back(op->operation);
         return (PyObject*)res;
     }
     return NULL;
@@ -157,8 +148,31 @@ static PySequenceMethods Oplist_as_sequence = {
     NULL                             /* sq_ass_slice */
 };
 
+static inline void addToOplist(PyOperation * op, PyOplist * o)
+{
+    if (op != NULL) {
+       if (PyOperation_Check(op)) {
+           o->ops->push_back(op->operation);
+       } else if ((PyObject*)op != Py_None) {
+           PyErr_SetString(PyExc_TypeError, "Argument must be an op");
+           return;
+       }
+    }
+}
 
-
+static int Oplist_init(PyOplist * self, PyObject * args, PyObject * kwds)
+{
+    PyOperation *op1 = NULL, *op2 = NULL, *op3 = NULL, *op4 = NULL;
+    if (!PyArg_ParseTuple(args, "|OOOO", &op1, &op2, &op3, &op4)) {
+        return -1;
+    }
+    self->ops = new OpVector();
+    addToOplist(op1, self);
+    addToOplist(op2, self);
+    addToOplist(op3, self);
+    addToOplist(op4, self);
+    return 0;
+}
 
 static PyNumberMethods Oplist_as_number = {
         (binaryfunc)Oplist_num_add,
@@ -189,13 +203,13 @@ static PyNumberMethods Oplist_as_number = {
 PyTypeObject PyOplist_Type = {
         PyObject_HEAD_INIT(&PyType_Type)
         0,                              /*ob_size*/
-        "Oplist",                       /*tp_name*/
+        "atlas.Oplist",                       /*tp_name*/
         sizeof(PyOplist),               /*tp_basicsize*/
         0,                              /*tp_itemsize*/
         /* methods */
         (destructor)Oplist_dealloc,     /*tp_dealloc*/
         0,                              /*tp_print*/
-        (getattrfunc)Oplist_getattr,    /*tp_getattr*/
+        0,                              /*tp_getattr*/
         0,                              /*tp_setattr*/
         0,                              /*tp_compare*/
         0,                              /*tp_repr*/
@@ -203,14 +217,33 @@ PyTypeObject PyOplist_Type = {
         &Oplist_as_sequence,            /*tp_as_sequence*/
         &Oplist_as_mapping,             /*tp_as_mapping*/
         0,                              /*tp_hash*/
+        0,                              // tp_call
+        0,                              // tp_str
+        0,                              // tp_getattro
+        0,                              // tp_setattro
+        0,                              // tp_as_buffer
+        Py_TPFLAGS_DEFAULT,             // tp_flags
+        "Oplist objects",               // tp_doc
+        0,                              // tp_travers
+        0,                              // tp_clear
+        0,                              // tp_richcompare
+        0,                              // tp_weaklistoffset
+        0,                              // tp_iter
+        0,                              // tp_iternext
+        Oplist_methods,                 // tp_methods
+        0,                              // tp_members
+        0,                              // tp_getset
+        0,                              // tp_base
+        0,                              // tp_dict
+        0,                              // tp_descr_get
+        0,                              // tp_descr_set
+        0,                              // tp_dictoffset
+        (initproc)Oplist_init,          // tp_init
+        0,                              // tp_alloc
+        0,                              // tp_new
 };
 
 PyOplist * newPyOplist()
 {
-        PyOplist * self;
-        self = PyObject_NEW(PyOplist, &PyOplist_Type);
-        if (self == NULL) {
-                return NULL;
-        }
-        return self;
+    return (PyOplist *)PyOplist_Type.tp_new(&PyOplist_Type, 0, 0);
 }
