@@ -15,12 +15,14 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 8c82e6d1d2b50192c681211f041fbbab8b99a653 $
 
 #include "Py_Point3D.h"
 
 #include "Py_Vector3D.h"
-#include "Py_Object.h"
+#include "Py_Message.h"
+
+#include <Atlas/Message/Element.h>
 
 static PyObject * Point3D_mag(PyPoint3D * self)
 {
@@ -34,11 +36,10 @@ static PyObject *Point3D_unit_vector_to(PyPoint3D * self, PyPoint3D * other)
         return NULL;
     }
     PyVector3D * ret = newPyVector3D();
-    if (ret == NULL) {
-        return NULL;
+    if (ret != NULL) {
+        ret->coords = (other->coords - self->coords);
+        ret->coords.normalize();
     }
-    ret->coords = (other->coords - self->coords);
-    ret->coords.normalize();
     return (PyObject *)ret;
 }
 
@@ -102,9 +103,6 @@ static PyObject * Point3D_getattr(PyPoint3D *self, char *name)
 
 static int Point3D_compare(PyPoint3D * self, PyPoint3D * other)
 {
-    if (!PyPoint3D_Check(other)) {
-        return -1;
-    }
     if (self->coords == other->coords) {
         return 0;
     }
@@ -118,10 +116,9 @@ static PyPoint3D * Point3D_num_add(PyPoint3D * self, PyVector3D*other)
         return NULL;
     }
     PyPoint3D * ret = newPyPoint3D();
-    if (ret == NULL) {
-        return NULL;
+    if (ret != NULL) {
+        ret->coords = (self->coords + other->coords);
     }
-    ret->coords = (self->coords + other->coords);
     return ret;
 }
 
@@ -130,18 +127,16 @@ static PyObject * Point3D_num_sub(PyPoint3D * self, PyObject * other)
     if (PyVector3D_Check(other)) {
         PyVector3D * ovec = (PyVector3D *)other;
         PyPoint3D * ret = newPyPoint3D();
-        if (ret == NULL) {
-            return NULL;
+        if (ret != NULL) {
+            ret->coords = (self->coords - ovec->coords);
         }
-        ret->coords = (self->coords - ovec->coords);
         return (PyObject *)ret;
     } else if (PyPoint3D_Check(other)) {
         PyPoint3D * opoint = (PyPoint3D *)other;
         PyVector3D * ret = newPyVector3D();
-        if (ret == NULL) {
-            return NULL;
+        if (ret != NULL) {
+            ret->coords = (self->coords - opoint->coords);
         }
-        ret->coords = (self->coords - opoint->coords);
         return (PyObject *)ret;
     } else {
         PyErr_SetString(PyExc_TypeError, "Can only subtract Vector3D or Point3D from Point3D");
@@ -175,8 +170,8 @@ static int Point3D_init(PyPoint3D * self, PyObject * args, PyObject * kwds)
                     self->coords[i] = (float)PyInt_AsLong(item);
                 } else if (PyFloat_Check(item)) {
                     self->coords[i] = PyFloat_AsDouble(item);
-                } else if (PyMessageElement_Check(item)) {
-                    PyMessageElement * mitem = (PyMessageElement*)item;
+                } else if (PyMessage_Check(item)) {
+                    PyMessage * mitem = (PyMessage*)item;
                     if (!mitem->m_obj->isNum()) {
                         PyErr_SetString(PyExc_TypeError, "Point3D() must take list of floats, or ints");
                         return -1;
@@ -252,7 +247,7 @@ static PyNumberMethods Point3D_num = {
 PyTypeObject PyPoint3D_Type = {
         PyObject_HEAD_INIT(0)
         0,                              // ob_size
-        "Point3D.Point3D",              // tp_name
+        "physics.Point3D",              // tp_name
         sizeof(PyPoint3D),              // tp_basicsize
         0,                              // tp_itemsize
         //  methods 
@@ -294,15 +289,5 @@ PyTypeObject PyPoint3D_Type = {
 
 PyPoint3D * newPyPoint3D()
 {
-#if 0
-    PyPoint3D * self;
-    self = PyObject_NEW(PyPoint3D, &PyPoint3D_Type);
-    if (self == NULL) {
-            return NULL;
-    }
-    new (&(self->coords)) Point3D();
-    return self;
-#else
     return (PyPoint3D *)PyPoint3D_Type.tp_new(&PyPoint3D_Type, 0, 0);
-#endif
 }
