@@ -15,13 +15,15 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Py_Point3D.h,v 1.9 2007-07-03 01:22:47 alriddoch Exp $
+// $Id$
 
-#ifndef RULESETS_PY_POINT3D_H
-#define RULESETS_PY_POINT3D_H
+#ifndef RULESETS_PY_POINT_3D_H
+#define RULESETS_PY_POINT_3D_H
 
 #include <Python.h>
 
+#include <wfmath/point.h>
+
 #include "physics/Vector3D.h"
 
 /// \brief Wrapper for Point3D in Python
@@ -41,4 +43,4 @@ extern PyTypeObject PyPoint3D_Type;
 
 PyPoint3D * newPyPoint3D();
 
-#endif // RULESETS_PY_POINT3D_H
+#endif // RULESETS_PY_POINT_3D_H
