@@ -15,10 +15,10 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Py_RootEntity.h,v 1.6 2006-12-24 17:18:55 alriddoch Exp $
+// $Id$
 
-#ifndef RULESETS_PY_ENTITY_H
-#define RULESETS_PY_ENTITY_H
+#ifndef RULESETS_PY_ROOT_ENTITY_H
+#define RULESETS_PY_ROOT_ENTITY_H
 
 #include <Python.h>
 
@@ -50,4 +50,4 @@ extern PyTypeObject PyConstRootEntity_Type;
 PyRootEntity * newPyRootEntity();
 PyConstRootEntity * newPyConstRootEntity();
 
-#endif // RULESETS_PY_ENTITY_H
+#endif // RULESETS_PY_ROOT_ENTITY_H
