@@ -15,12 +15,13 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 22f5a557e0a5bd402392b02c7bfe3ed18e2441d4 $
 
 #include "Py_Task.h"
 
-#include "Py_Thing.h"
+#include "Py_Message.h"
 #include "Py_Operation.h"
+#include "Py_Thing.h"
 #include "PythonWrapper.h"
 
 #include "TaskScript.h"
@@ -110,10 +111,10 @@ static PyMethodDef Task_methods[] = {
 static void Task_dealloc(PyTask *self)
 {
     Py_XDECREF(self->Task_attr);
-    PyObject_Free(self);
+    self->ob_type->tp_free((PyObject*)self);
 }
 
-static PyObject * Task_getattr(PyTask *self, char *name)
+static PyObject * Task_getattro(PyTask *self, PyObject *oname)
 {
     // Fairly major re-write of this to use operator[] of Task base class
 #ifndef NDEBUG
@@ -122,6 +123,7 @@ static PyObject * Task_getattr(PyTask *self, char *name)
         return NULL;
     }
 #endif // NDEBUG
+    char * name = PyString_AsString(oname);
     if (strcmp(name, "character") == 0) {
         return wrapEntity(&self->m_task->character());
     }
@@ -131,6 +133,10 @@ static PyObject * Task_getattr(PyTask *self, char *name)
     if (strcmp(name, "rate") == 0) {
         return PyFloat_FromDouble(self->m_task->rate());
     }
+    Atlas::Message::Element val;
+    if (self->m_task->getAttr(name, val)) {
+        return MessageElement_asPyObject(val);
+    }
     if (self->Task_attr != NULL) {
         PyObject *v = PyDict_GetItemString(self->Task_attr, name);
         if (v != NULL) {
@@ -138,10 +144,10 @@ static PyObject * Task_getattr(PyTask *self, char *name)
             return v;
         }
     }
-    return Py_FindMethod(Task_methods, (PyObject *)self, name);
+    return PyObject_GenericGetAttr((PyObject *)self, oname);
 }
 
-static int Task_setattr(PyTask *self, char *name, PyObject *v)
+static int Task_setattro(PyTask *self, PyObject * oname, PyObject *v)
 {
 #ifndef NDEBUG
     if (self->m_task == NULL) {
@@ -149,6 +155,7 @@ static int Task_setattr(PyTask *self, char *name, PyObject *v)
         return -1;
     }
 #endif // NDEBUG
+    char * name = PyString_AsString(oname);
     if (strcmp(name, "progress") == 0) {
         if (PyFloat_Check(v)) {
             self->m_task->progress() = PyFloat_AsDouble(v);
@@ -185,13 +192,47 @@ static int Task_setattr(PyTask *self, char *name, PyObject *v)
 
 static int Task_compare(PyTask *self, PyTask *other)
 {
+#ifndef NDEBUG
     if (self->m_task == NULL || other->m_task == NULL) {
         PyErr_SetString(PyExc_AssertionError, "NULL Task in Task.compare");
         return -1;
     }
+#endif // NDEBUG
     return (self->m_task == other->m_task) ? 0 : 1;
 }
 
+static int Task_init(PyTask * self, PyObject * args, PyObject * kwds)
+{
+    PyObject * arg;
+    if (!PyArg_ParseTuple(args, "O", &arg)) {
+        return -1;
+    }
+    if (PyTask_Check(arg)) {
+        PyTask * wrap_task = (PyTask *)arg;
+#ifndef NDEBUG
+        if (wrap_task->m_task == NULL) {
+            PyErr_SetString(PyExc_AssertionError, "NULL task Task.__init__");
+            return -1;
+        }
+#endif // NDEBUG
+        self->m_task = wrap_task->m_task;
+        return 0;
+    }
+    if (PyCharacter_Check(arg)) {
+        PyEntity * character = (PyEntity *)arg;
+#ifndef NDEBUG
+        if (character->m_entity.c == NULL) {
+            PyErr_SetString(PyExc_AssertionError, "NULL character Task.__init__");
+            return -1;
+        }
+#endif // NDEBUG
+        self->m_task = new TaskScript(*character->m_entity.c);
+        return 0;
+    }
+    PyErr_SetString(PyExc_TypeError, "Task requires a Task, or Character");
+    return -1;
+}
+
 PyTypeObject PyTask_Type = {
         PyObject_HEAD_INIT(&PyType_Type)
         0,                              /*ob_size*/
@@ -201,14 +242,38 @@ PyTypeObject PyTask_Type = {
         /* methods */
         (destructor)Task_dealloc,       /*tp_dealloc*/
         0,                              /*tp_print*/
-        (getattrfunc)Task_getattr,      /*tp_getattr*/
-        (setattrfunc)Task_setattr,      /*tp_setattr*/
+        0,                              /*tp_getattr*/
+        0,                              /*tp_setattr*/
         (cmpfunc)Task_compare,          /*tp_compare*/
         0,                              /*tp_repr*/
         0,                              /*tp_as_number*/
         0,                              /*tp_as_sequence*/
         0,                              /*tp_as_mapping*/
         0,                              /*tp_hash*/
+        0,                              // tp_call
+        0,                              // tp_str
+        (getattrofunc)Task_getattro,    // tp_getattro
+        (setattrofunc)Task_setattro,    // tp_setattro
+        0,                              // tp_as_buffer
+        Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,             // tp_flags
+        "Task objects",                 // tp_doc
+        0,                              // tp_travers
+        0,                              // tp_clear
+        0,                              // tp_richcompare
+        0,                              // tp_weaklistoffset
+        0,                              // tp_iter
+        0,                              // tp_iternext
+        Task_methods,                   // tp_methods
+        0,                              // tp_members
+        0,                              // tp_getset
+        0,                              // tp_base
+        0,                              // tp_dict
+        0,                              // tp_descr_get
+        0,                              // tp_descr_set
+        0,                              // tp_dictoffset
+        (initproc)Task_init,            // tp_init
+        0,                              // tp_alloc
+        0,                              // tp_new
 };
 
 PyObject * wrapTask(Task * task)
@@ -218,7 +283,9 @@ PyObject * wrapTask(Task * task)
     PythonWrapper * pw;
     if (ts == 0 || ((pw = dynamic_cast<PythonWrapper *>(ts->script())) == 0)) {
         PyTask * pt = newPyTask();
-        pt->m_task = task;
+        if (pt != NULL) {
+            pt->m_task = task;
+        }
         wrapper = (PyObject *)pt;
         // This wrapper cannot be stashed back int the task yet so
         // we don't have to do this next time.
@@ -232,11 +299,5 @@ PyObject * wrapTask(Task * task)
 
 PyTask * newPyTask()
 {
-    PyTask * self;
-    self = PyObject_NEW(PyTask, &PyTask_Type);
-    if (self == NULL) {
-        return NULL;
-    }
-    self->Task_attr = NULL;
-    return self;
+    return (PyTask *)PyTask_Type.tp_new(&PyTask_Type, 0, 0);
 }
