@@ -15,11 +15,12 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: ede38e15e9deb14931f6b4f9ad7a4859fdd01d3f $
 
 #include "Py_Property.h"
 
 #include "Py_Point3D.h"
+#include "Py_Vector3D.h"
 
 #include "TerrainProperty.h"
 
@@ -36,8 +37,11 @@ static PyObject * TerrainProperty_getHeight(PyTerrainProperty * self,
     if (!PyArg_ParseTuple(args, "ff", &x, &y)) {
         return NULL;
     }
-    float height = self->m_property->getHeight(x, y);
-    return PyFloat_FromDouble(height);
+    // Return a sensible default.
+    Vector3D normal(0,0,1);
+    float h = 0;
+    self->m_property->getHeightAndNormal(x, y, h, normal);
+    return PyFloat_FromDouble(h);
 }
 
 static PyObject * TerrainProperty_getSurface(PyTerrainProperty * self,
@@ -65,9 +69,34 @@ static PyObject * TerrainProperty_getSurface(PyTerrainProperty * self,
     return PyInt_FromLong(surface);
 }
 
+static PyObject * TerrainProperty_getNormal(PyTerrainProperty * self,
+                                            PyObject * args)
+{
+#ifndef NDEBUG
+    if (self->m_entity == NULL) {
+        PyErr_SetString(PyExc_AssertionError, "NULL entity in TerrainProperty.getattr");
+        return NULL;
+    }
+#endif
+    float x,y;
+    if (!PyArg_ParseTuple(args, "ff", &x, &y)) {
+        return NULL;
+    }
+    // Return a sensible default.
+    Vector3D normal(0,0,1);
+    float h = 0;
+    self->m_property->getHeightAndNormal(x, y, h, normal);
+    PyVector3D * ret = newPyVector3D();
+    if (ret != NULL) {
+        ret->coords = normal;
+    }
+    return (PyObject *)ret;
+}
+
 static PyMethodDef TerrainProperty_methods[] = {
     {"get_height",   (PyCFunction)TerrainProperty_getHeight,     METH_VARARGS},
     {"get_surface",  (PyCFunction)TerrainProperty_getSurface,    METH_VARARGS},
+    {"get_normal",   (PyCFunction)TerrainProperty_getNormal,	 METH_VARARGS},
     {NULL,           NULL}           /* sentinel */
 };
 
@@ -101,25 +130,6 @@ static int TerrainProperty_setattr(PyTerrainProperty * self,
     return -1;
 }
 
-static int TerrainProperty_compare(PyTerrainProperty *self, PyTerrainProperty *other)
-{
-    if (self->m_entity == NULL || other->m_entity == NULL) {
-        PyErr_SetString(PyExc_AssertionError, "NULL entity in TerrainProperty.compare");
-        return -1;
-    }
-    return (self->m_entity == other->m_entity) ? 0 : 1;
-}
-
-static PyObject * TerrainProperty_new(PyTypeObject * type,
-                                      PyObject *,
-                                      PyObject *)
-{
-    // This looks allot like the default implementation, except we set some
-    // stuff to null.
-    PyTerrainProperty * self = (PyTerrainProperty *)type->tp_alloc(type, 0);
-    return (PyObject *)self;
-}
-
 static int TerrainProperty_init(PyTerrainProperty * self,
                                 PyObject * args,
                                 PyObject * kwd)
@@ -142,7 +152,7 @@ PyTypeObject PyTerrainProperty_Type = {
         0,                                                // tp_print
         (getattrfunc)TerrainProperty_getattr,             // tp_getattr
         (setattrfunc)TerrainProperty_setattr,             // tp_setattr
-        (cmpfunc)TerrainProperty_compare,                 // tp_compare
+        0,                                                // tp_compare
         0,                                                // tp_repr
         0,                                                // tp_as_number
         0,                                                // tp_as_sequence
@@ -171,15 +181,10 @@ PyTypeObject PyTerrainProperty_Type = {
         0,                                                // tp_dictoffset
         (initproc)TerrainProperty_init,                   // tp_init
         0,                                                // tp_alloc
-        TerrainProperty_new,                              // tp_new
+        0,                                                // tp_new
 };
 
 PyTerrainProperty * newPyTerrainProperty()
 {
-    PyTerrainProperty * self;
-    self = PyObject_NEW(PyTerrainProperty, &PyTerrainProperty_Type);
-    if (self == NULL) {
-        return NULL;
-    }
-    return self;
+    return (PyTerrainProperty *)PyTerrainProperty_Type.tp_new(&PyTerrainProperty_Type, 0, 0);
 }
