@@ -15,12 +15,14 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: cd846796e470ca94e851f5f39c59c9e19bd6741f $
 
 #include "Py_Vector3D.h"
 
 #include "Py_Quaternion.h"
-#include "Py_Object.h"
+#include "Py_Message.h"
+
+#include <Atlas/Message/Element.h>
 
 static PyObject * Vector3D_dot(PyVector3D * self, PyVector3D * other)
 {
@@ -38,10 +40,9 @@ static PyObject * Vector3D_cross(PyVector3D * self, PyVector3D * other)
         return NULL;
     }
     PyVector3D * ret = newPyVector3D();
-    if (ret == NULL) {
-        return NULL;
+    if (ret != NULL) {
+        ret->coords = Cross(self->coords, other->coords);
     }
-    ret->coords = Cross(self->coords, other->coords);
     return (PyObject *)ret;
 }
 
@@ -227,9 +228,6 @@ static int Vector3D_setattr(PyVector3D *self, char *name, PyObject *v)
 
 static int Vector3D_compare(PyVector3D * self, PyVector3D * other)
 {
-    if (!PyVector3D_Check(other)) {
-        return -1;
-    }
     if (self->coords == other->coords) {
         return 0;
     }
@@ -243,10 +241,9 @@ static PyVector3D*Vector3D_num_add(PyVector3D*self,PyVector3D*other)
         return NULL;
     }
     PyVector3D * ret = newPyVector3D();
-    if (ret == NULL) {
-        return NULL;
+    if (ret != NULL) {
+        ret->coords = (self->coords + other->coords);
     }
-    ret->coords = (self->coords + other->coords);
     return ret;
 }
 
@@ -257,10 +254,9 @@ static PyVector3D*Vector3D_num_sub(PyVector3D*self,PyVector3D*other)
         return NULL;
     }
     PyVector3D * ret = newPyVector3D();
-    if (ret == NULL) {
-        return NULL;
+    if (ret != NULL) {
+        ret->coords = (self->coords - other->coords);
     }
-    ret->coords = (self->coords - other->coords);
     return ret;
 }
 
@@ -276,10 +272,9 @@ static PyVector3D * Vector3D_num_mul(PyVector3D * self, PyObject * _other)
         return NULL;
     }
     PyVector3D * ret = newPyVector3D();
-    if (ret == NULL) {
-        return NULL;
+    if (ret != NULL) {
+        ret->coords = (self->coords * other);
     }
-    ret->coords = (self->coords * other);
     return ret;
 }
 
@@ -295,10 +290,9 @@ static PyVector3D * Vector3D_num_div(PyVector3D * self, PyObject * _other)
         return NULL;
     }
     PyVector3D * ret = newPyVector3D();
-    if (ret == NULL) {
-        return NULL;
+    if (ret != NULL) {
+        ret->coords = (self->coords / other);
     }
-    ret->coords = (self->coords / other);
     return ret;
 }
 
@@ -327,8 +321,8 @@ static int Vector3D_init(PyVector3D * self, PyObject * args, PyObject * kwds)
                     self->coords[i] = (float)PyInt_AsLong(item);
                 } else if (PyFloat_Check(item)) {
                     self->coords[i] = PyFloat_AsDouble(item);
-                } else if (PyMessageElement_Check(item)) {
-                    PyMessageElement * mitem = (PyMessageElement*)item;
+                } else if (PyMessage_Check(item)) {
+                    PyMessage * mitem = (PyMessage*)item;
                     if (!mitem->m_obj->isNum()) {
                         PyErr_SetString(PyExc_TypeError, "Vector3D() must take list of floats, or ints");
                         return -1;
@@ -404,7 +398,7 @@ static PyNumberMethods Vector3D_num = {
 PyTypeObject PyVector3D_Type = {
         PyObject_HEAD_INIT(0)
         0,                              // ob_size
-        "Vector3D.Vector3D",            // tp_name
+        "physics.Vector3D",             // tp_name
         sizeof(PyVector3D),             // tp_basicsize
         0,                              // tp_itemsize
         // methods 
@@ -446,15 +440,5 @@ PyTypeObject PyVector3D_Type = {
 
 PyVector3D * newPyVector3D()
 {
-#if 0
-    PyVector3D * self;
-    self = PyObject_NEW(PyVector3D, &PyVector3D_Type);
-    if (self == NULL) {
-            return NULL;
-    }
-    new (&(self->coords)) Vector3D();
-    return self;
-#else
     return (PyVector3D *)PyVector3D_Type.tp_new(&PyVector3D_Type, 0, 0);
-#endif
 }
