@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 3f06110386d7974a9b3484ef2b7e38a4446cf5d2 $
 
 #include "Py_WorldTime.h"
 
@@ -75,25 +75,15 @@ static PyObject * WorldTime_getattr(PyWorldTime *self, char *name)
     return Py_FindMethod(WorldTime_methods, (PyObject *)self, name);
 }
 
-static int WorldTime_cmp(PyWorldTime *self, PyObject *other)
-{
-    if (PyString_Check(other)) {
-        printf("Python compare of worldtime to string\n");
-        bool eq = (*self->time == std::string(PyString_AsString(other)));
-        return eq ? 0 : -1;
-    } else {
-        printf("Python compare of worldtime to ?\n");
-        return -1;
-    }
-}
-
 static PyObject * WorldTime_new(PyTypeObject * type, PyObject *, PyObject *)
 {
     // This looks allot like the default implementation, except we set some
     // stuff to null.
     PyWorldTime * self = (PyWorldTime *)type->tp_alloc(type, 0);
-    self->time = 0;
-    self->own = false;
+    if (self != NULL) {
+        self->time = 0;
+        self->own = false;
+    }
     return (PyObject *)self;
 }
 
@@ -122,7 +112,7 @@ PyTypeObject PyWorldTime_Type = {
         0,                              // tp_print
         (getattrfunc)WorldTime_getattr, // tp_getattr
         0,                              // tp_setattr
-        (cmpfunc)WorldTime_cmp,         // tp_compare
+        0,                              // tp_compare
         0,                              // tp_repr
         0,                              // tp_as_number
         0,                              // tp_as_sequence
@@ -156,11 +146,5 @@ PyTypeObject PyWorldTime_Type = {
 
 PyWorldTime * newPyWorldTime()
 {
-    PyWorldTime * self;
-    self = PyObject_NEW(PyWorldTime, &PyWorldTime_Type);
-    if (self == NULL) {
-        return NULL;
-    }
-    self->own = false;
-    return self;
+    return (PyWorldTime *)PyWorldTime_Type.tp_new(&PyWorldTime_Type, 0, 0);
 }
