@@ -15,20 +15,17 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: f7f7862f2b38a035cd3b6b32d208a03483c2658b $
 
 #ifndef RULESETS_PYTHON_CONTEXT_H
 #define RULESETS_PYTHON_CONTEXT_H
 
 #include <string>
 
-struct _object;
-
-typedef struct _object PyObject;
-
+/// \brief Handle running python commands in the servers interpreter context
 class PythonContext {
   protected:
-    PyObject * m_context;
+    struct _object * m_context;
   public:
     PythonContext();
 
