@@ -15,26 +15,25 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 8db3f88b3b61abd1ab8c51d86d8aaef25f3ba159 $
 
 #ifndef RULESETS_PYTHON_WRAPPER_H
 #define RULESETS_PYTHON_WRAPPER_H
 
-#include <Python.h>
-
 #include "Script.h"
 
 /// \brief Wrapper class for entities without scripts but with wrappers
+/// \ingroup Scripts
 class PythonWrapper : public Script {
   protected:
     /// \brief Python object that wraps the entity.
-    PyObject * m_wrapper;
+    struct _object * m_wrapper;
   public:
-    explicit PythonWrapper(PyObject * wrapper);
+    explicit PythonWrapper(struct _object * wrapper);
     virtual ~PythonWrapper();
 
     /// \brief Accessor for the python object that wraps the entity.
-    PyObject * wrapper() const { return m_wrapper; }
+    struct _object * wrapper() const { return m_wrapper; }
 };
 
 #endif // RULESETS_PYTHON_WRAPPER_H
