@@ -15,22 +15,22 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 84e1f46fa4e4039b4aca544939aff6ebebfb0fd7 $
 
 #ifndef RULESETS_PYTHON_SCRIPT_UTILS_H
 #define RULESETS_PYTHON_SCRIPT_UTILS_H
 
-#include <Python.h>
-
 #include <string>
 
 class BaseMind;
 class Entity;
 
-void Create_PyEntity(Entity * entity, const std::string & package,
-                                    const std::string & type);
+struct _object * Get_PyClass(struct _object * module,
+                       const std::string & package,
+                       const std::string & type);
+struct _object * Get_PyModule(const std::string & package);
 void Create_PyMind(BaseMind * mind, const std::string & package,
                                     const std::string & type);
-PyObject * Create_PyScript(PyObject *, PyObject *);
+struct _object * Create_PyScript(struct _object *, struct _object *);
 
 #endif // RULESETS_PYTHON_SCRIPT_UTILS_H
