@@ -15,17 +15,13 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 23e15160b964ce38c1ac80eb01bfb41a017744c9 $
 
 #ifndef RULESETS_SOLID_PROPERTY_H
 #define RULESETS_SOLID_PROPERTY_H
 
 #include "common/Property.h"
 
-#include "physics/Vector3D.h"
-
-#include <set>
-
 class Entity;
 
 /// \brief Class to handle whether or not an entity is solid for collisions.
