@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 7cfc11a95397a7bc3ef33b1baaa395c4f2b47ce6 $
 
 #include <Python.h>
 
@@ -39,7 +39,7 @@ using Atlas::Message::FloatType;
 ///
 /// @param data variable that holds the Property value
 /// @param flags flags to indicate how this property is stored
-StatisticsProperty::StatisticsProperty() : PropertyBase(0), m_script(0)
+StatisticsProperty::StatisticsProperty() : m_script(0)
 {
 }
 
