@@ -15,13 +15,15 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 0efdfde4ee07ff6fb9a13c3bad3c58b5706d755a $
 
 #ifndef RULESETS_TASK_H
 #define RULESETS_TASK_H
 
 #include "common/OperationRouter.h"
 
+#include <Atlas/Message/Element.h>
+
 #include <string>
 
 #include <cassert>
@@ -55,6 +57,9 @@ class Task {
     /// involved.
     Character & m_character;
 
+    /// \brief Additional task attributes
+    Atlas::Message::MapType m_attr;
+
     /// \brief Name of task presented to client
     std::string m_name;
 
@@ -138,6 +143,12 @@ class Task {
 
     /// \brief Accessor for rate of progress towards completion
     float & rate() { return m_rate; }
+
+    /// \brief Accessor for additional attributes
+    bool getAttr(const std::string & attr, Atlas::Message::Element & val) const;
+
+    /// \brief Sets additional attribute
+    void setAttr(const std::string & attr, const Atlas::Message::Element & val);
 };
 
 #endif // RULESETS_TASK_H
