@@ -15,11 +15,12 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 90373c0e24b1f31e5fbab724add7383ba92a11fc $
 
 #include "Thing.h"
 
 #include "Motion.h"
+#include "Domain.h"
 
 #include "common/log.h"
 #include "common/const.h"
@@ -225,9 +226,9 @@ void Thing::MoveOperation(const Operation & op, OpVector & res)
     // Update pos
     fromStdVector(m_location.m_pos, ent->getPos());
     // FIXME Quick height hack
-    m_location.m_pos.z() = BaseWorld::instance().constrainHeight(m_location.m_loc,
-                                                    m_location.pos(),
-                                                    mode);
+    m_location.m_pos.z() = getMovementDomain()->constrainHeight(m_location.m_loc,
+                                                               m_location.pos(),
+                                                               mode);
     m_location.update(current_time);
     m_flags &= ~(entity_pos_clean | entity_clean);
 
@@ -554,9 +555,10 @@ void Thing::UpdateOperation(const Operation & op, OpVector & res)
 
     // Adjust the position to world constraints - essentially fit
     // to the terrain height at this stage.
-    m_location.m_pos.z() = BaseWorld::instance().constrainHeight(m_location.m_loc,
+    // FIXME Get the constraints from the movement domain
+    m_location.m_pos.z() = getMovementDomain()->constrainHeight(m_location.m_loc,
                                                     m_location.pos(),
-                                                    mode);
+                                                    "standing");
     m_location.update(current_time);
     m_flags &= ~(entity_pos_clean | entity_clean);
 
