@@ -5,12 +5,13 @@ import random
 
 from atlas import *
 from physics import *
-from Quaternion import Quaternion
+from physics import Quaternion
 from common import const
 from types import *
 
-from Vector3D import Vector3D
-from cyphesis.Thing import Thing
+from physics import Vector3D
+
+import server
 
 from mind.Memory import Memory
 from mind.Knowledge import Knowledge
@@ -31,7 +32,7 @@ def get_dict_func(self, func_str, func_undefined):
         func=func_undefined
     return func
 
-class NPCMind(Thing):
+class NPCMind(server.Mind):
     """Mind class for most mobile entities in the game.
 
     An NPCMind object is associated with all NPC and similar entities on a
@@ -52,7 +53,7 @@ class NPCMind(Thing):
     are activated by an event."""
     ########## Initialization
     def __init__(self, cppthing):
-        self.cinit(cppthing)
+        self.mind = cppthing
 
         self.knowledge=Knowledge()
         self.mem=Memory(map=self.map)
@@ -92,7 +93,7 @@ class NPCMind(Thing):
         #print "Map add",obj
         pass
     def update_map(self, obj):
-        """Hook called by underlying map code when an entity is added.
+        """Hook called by underlying map code when an entity is updated.
 
         Fix ownership category for objects owned temporary under 'Foo' type."""
         #print "Map update",obj
@@ -103,7 +104,7 @@ class NPCMind(Thing):
                 self.remove_thing(foo)
                 self.add_thing(obj)
     def delete_map(self, obj):
-        """Hook called by underlying map code when an entity is added."""
+        """Hook called by underlying map code when an entity is deleted."""
         #print "Map delete",obj
         self.remove_thing(obj)
     ########## Operations
@@ -137,7 +138,7 @@ class NPCMind(Thing):
         if op.to==self.id:
             self.add_thing(obj)
     def sight_move_operation(self, op):
-        """change position in out local map"""
+        """change position in our local map"""
         obj=self.map.update(op[0], op.getSeconds())
         if obj.location.parent.id==self.id:
             self.add_thing(obj)
@@ -176,7 +177,7 @@ class NPCMind(Thing):
         verb=interlinguish.get_verb(object)
         operation_method=self.find_op_method(verb,"interlinguish_desire_verb3_",
                                              self.interlinguish_undefined_operation)
-        res = Message()
+        res = Oplist()
         res = res + self.call_interlinguish_triggers(verb, "interlinguish_desire_verb3_", op, object)
         res = res + operation_method(op, object)
         return res
@@ -257,7 +258,7 @@ class NPCMind(Thing):
         if not hasattr(self.knowledge, predicate):
             return None
         d=getattr(self.knowledge, predicate)
-        res = Message()
+        res = Oplist()
         res = res + self.face(self.map.get(op.to))
         for key in d:
             res = res + Operation('talk',
@@ -335,13 +336,13 @@ class NPCMind(Thing):
         # the result.
         null_name, sub_op = self.get_op_name_and_sub(op)
         event_name = prefix+verb
-        reply = Message()
+        reply = Oplist()
         for goal in self.trigger_goals.get(event_name,[]):
             reply += goal.event(self, op, say)
         return reply
     def call_triggers_operation(self, op):
         event_name, sub_op = self.get_op_name_and_sub(op)
-        reply = Message()
+        reply = Oplist()
         for goal in self.trigger_goals.get(event_name,[]):
             reply += goal.event(self, op, sub_op)
         return reply
@@ -471,7 +472,7 @@ class NPCMind(Thing):
             if res: return res
             # if res!=None: return res
     def teach_children(self, child):
-        res=Message()
+        res=Oplist()
         for k in self.knowledge.location.keys():
             es=Entity(verb='know',subject=k,object=self.knowledge.location[k])
             res.append(Operation('say',es,to=child))
@@ -499,7 +500,7 @@ class NPCMind(Thing):
     ########## communication: here send it locally
     def send(self, op):
         if not self.message_queue:
-            self.message_queue=Message(op)
+            self.message_queue=Oplist(op)
         else:
             self.message_queue.append(op)
     ########## turn to face other entity
