@@ -4,8 +4,8 @@
 from atlas import *
 from random import *
 from cyphesis.editor import editor
-from Quaternion import Quaternion
-from Vector3D import Vector3D
+from physics import Quaternion
+from physics import Vector3D
 from math import *
 
 import time
