@@ -2,20 +2,16 @@
 #Copyright (C) 1999 Aloril (See the file COPYING for details).
 from atlas import *
 
-from cyphesis.Thing import Thing
-try:
-  from random import *
-except ImportError:
-  from whrandom import *
-from Vector3D import Vector3D
+from random import *
 
 import atlas
+import server
 
 class Deer(Thing):
     def chop_operation(self, op):
         if self.mass<1:
             return(Operation("set",Entity(self.id,status=-1),to=self))
-        res = Message()
+        res = Oplist()
         ent=Entity(self.id,mode="dead",mass=self.mass-1)
         res.append(Operation("set",ent,to=self))
         venison_ent=Entity(name='venison',parents=['venison'])
