@@ -4,12 +4,10 @@
 
 from atlas import *
 
-from cyphesis.Thing import Thing
-
-class Axe(Thing):
+class Axe(server.Thing):
     """This is base class for axes, this one just ordinary axe"""
     def cut_operation(self, op):
         print "Axe.cut_operation() Don't call this."
         ent=Entity(self.id,status=self.status-0.01)
         to_ = op[0].id
-        return Message(Operation("set",ent,to=self),Operation("chop",op[0],to=to_))
+        return Oplist(Operation("set",ent,to=self),Operation("chop",op[0],to=to_))
