@@ -2,17 +2,15 @@
 #Copyright (C) 1999 Al Riddoch (See the file COPYING for details).
 
 from atlas import *
-from cyphesis.Thing import Thing
 from common import log,const
-from Vector3D import Vector3D
-try:
-  from random import *
-except ImportError:
-  from whrandom import *
+from physics import Vector3D
+from random import *
 
-class Skeleton(Thing):
+import server
+
+class Skeleton(server.Character):
     def touch_operation(self, op):
-        retops = Message()
+        retops = Oplist()
         if self.status<0: return
         self.status=-1
         newloc=self.location.copy()
