@@ -3,14 +3,12 @@
 
 from atlas import *
 from physics import *
-from Quaternion import Quaternion
-from Vector3D import Vector3D
-
-from cyphesis.Thing import Thing
+from physics import Quaternion
+from physics import Vector3D
 
 import server
 
-class Reap(Thing):
+class Reap(server.Task):
     """ A task for cutting a log into boards."""
     def cut_operation(self, op):
         """ Op handler for cut op which activates this task """
@@ -60,7 +58,7 @@ class Reap(Thing):
             # print "Not grass"
             return self.next_tick(1.75)
 
-        res=Message()
+        res=Oplist()
 
         chunk_loc = Location(self.character.location.parent)
         chunk_loc.velocity = Vector3D()
