@@ -3,19 +3,14 @@
 
 from atlas import *
 from physics import *
-from Quaternion import Quaternion
-from Vector3D import Vector3D
+from physics import Quaternion
+from physics import Vector3D
 
-try:
-  from random import *
-except ImportError:
-  from whrandom import *
-
-from cyphesis.Thing import Thing
+from random import *
 
 import server
 
-class Trailblaze(Thing):
+class Trailblaze(server.Task):
     """ A proof of concept task for making new paths and roads."""
     def strike_operation(self, op):
         """ Op handler for strike op which activates this task """
@@ -35,7 +30,7 @@ class Trailblaze(Thing):
     def tick_operation(self, op):
         """ Op handler for regular tick op """
         # print "Trailblaze.tick"
-        res=Message()
+        res=Oplist()
 
         target=server.world.get_object(self.target)
         if not target:
