@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: CommMDNSPublisher.cpp,v 1.18 2007-12-05 01:01:51 alriddoch Exp $
+// $Id$
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -37,9 +37,9 @@
 #include "common/log.h"
 #include "common/const.h"
 #include "common/debug.h"
-#include "common/globals.h"
 #include "common/BaseWorld.h"
 #include "common/compose.hpp"
+#include "common/sockets.h"
 
 #include <iostream>
 
