@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: CommMaster.h,v 1.5 2006-12-22 02:14:44 alriddoch Exp $
+// $Id$
 
 #ifndef SERVER_COMM_MASTER_H
 #define SERVER_COMM_MASTER_H
@@ -26,9 +26,7 @@
 /// \ingroup ServerSockets
 class CommMaster : public CommClient {
   public:
-    CommMaster(CommServer & svr,
-               const std::string & addr,
-               const std::string & id);
+    CommMaster(CommServer & svr);
     virtual ~CommMaster();
 
     int connect(const std::string &);
