@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: CommPeer.cpp,v 1.5 2006-10-26 00:48:13 alriddoch Exp $
+// $Id$
 
 #include "CommPeer.h"
 
@@ -24,27 +24,15 @@
 
 #include "common/globals.h"
 
-/// \brief Constructor remote peer socket object.
-///
-/// @param svr Reference to the object that manages all socket communication.
-/// @param addr Address of the remote peer.
-CommPeer::CommPeer(CommServer & svr, const std::string & addr,
-                                     const std::string & id) :
-   CommClient(svr, *new Peer(*this, svr.m_server, addr, id))
-{
-    std::cout << "Outgoing peer connection." << std::endl << std::flush;
-}
+INT_OPTION(peer_port_num, 6769, CYPHESIS, "peerport",
+           "Network listen port for peer server connections");
 
 /// \brief Constructor remote peer socket object.
 ///
 /// @param svr Reference to the object that manages all socket communication.
-/// @param fd Socket file descriptor
-/// @param addr Address of the remote peer.
-CommPeer::CommPeer(CommServer & svr, int fd, const std::string & addr,
-                                             const std::string & id) :
-   CommClient(svr, fd, *new Peer(*this, svr.m_server, addr, id))
+CommPeer::CommPeer(CommServer & svr) : CommClient(svr)
 {
-    std::cout << "Incoming peer connection." << std::endl << std::flush;
+    std::cout << "Outgoing peer connection." << std::endl << std::flush;
 }
 
 CommPeer::~CommPeer()
