@@ -15,16 +15,13 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 083da3f21f5952ec01f7cf4a64ea252f2aedd585 $
 
 #ifndef SERVER_COMM_PYTHON_CLIENT_H
 #define SERVER_COMM_PYTHON_CLIENT_H
 
 #include "CommStreamClient.h"
 
-#include <skstream/skstream.h>
-
-#include <list>
 #include <string>
 
 class PythonContext;
