@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: CommUnixListener.cpp,v 1.28 2007-05-29 00:39:18 alriddoch Exp $
+// $Id$
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -23,7 +23,7 @@
 
 #include "CommUnixListener.h"
 
-#include "CommLocalClient.h"
+#include "CommClientFactory.h"
 #include "CommServer.h"
 
 #include "common/id.h"
@@ -45,44 +45,19 @@ static const bool debug_flag = false;
 /// \brief Constructor unix listen socket object.
 ///
 /// @param svr Reference to the object that manages all socket communication.
-CommUnixListener::CommUnixListener(CommServer & svr) : CommSocket(svr),
-                                                       m_bound(false)
+CommUnixListener::CommUnixListener(CommServer & svr, CommClientKit & kit) :
+                  CommStreamListener(svr, kit)
 {
+    m_listener = &m_unixListener;
 }
 
 CommUnixListener::~CommUnixListener()
 {
-    if (m_bound) {
+    if (m_unixListener.is_open()) {
         ::unlink(m_path.c_str());
     }
 }
 
-
-int CommUnixListener::getFd() const
-{
-    return m_unixListener.getSocket();
-}
-
-bool CommUnixListener::eof()
-{
-    return false;
-}
-
-bool CommUnixListener::isOpen() const
-{
-    return m_unixListener.is_open();
-}
-
-int CommUnixListener::read()
-{
-    accept();
-    return 0;
-}
-
-void CommUnixListener::dispatch()
-{
-}
-
 /// \brief Create and bind the listen socket.
 ///
 /// If an initial attempt fails, then this function attempts to unlink the
@@ -91,19 +66,19 @@ void CommUnixListener::dispatch()
 /// will never be called in an instance of cyphesis already exists.
 int CommUnixListener::setup(const std::string & name)
 {
-    m_path = var_directory + "/tmp/" + name;
+    m_path = name;
 
     m_unixListener.open(m_path);
-    m_bound = m_unixListener.is_open();
+    bool bound = m_unixListener.is_open();
 
-    if (!m_bound) {
+    if (!bound) {
         ::unlink(m_path.c_str());
 
         m_unixListener.open(m_path);
-        m_bound = m_unixListener.is_open();
+        bound = m_unixListener.is_open();
     }
 
-    return m_bound ? 0 : 1;
+    return bound ? 0 : 1;
 }
 
 /// \brief Accept a new connect to the listen socket.
@@ -117,28 +92,7 @@ int CommUnixListener::accept()
     }
     debug(std::cout << "Local accepted" << std::endl << std::flush;);
 
-    return create(asockfd);
-}
-
-int CommUnixListener::create(int asockfd)
-{
-    std::string connection_id;
-    if (newId(connection_id) < 0) {
-        log(ERROR, "Unable to accept connection as no ID available");
-        closesocket(asockfd);
-        return -1;
-    }
-
-    CommLocalClient * newcli = new CommLocalClient(m_commServer, asockfd,
-                                                   connection_id);
-
-    newcli->setup();
-
-    // Add this new client to the list.
-    m_commServer.addSocket(newcli);
-    m_commServer.addIdle(newcli);
-
-    return 0;
+    return create(asockfd, "local");
 }
 
 #endif // HAVE_SYS_UN_H
