@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Connection.cpp,v 1.173 2008-01-28 23:48:32 alriddoch Exp $
+// $Id$
 
 #include "Connection.h"
 
@@ -25,7 +25,7 @@
 #include "CommServer.h"
 #include "Player.h"
 #include "ExternalMind.h"
-#include "Persistance.h"
+#include "Persistence.h"
 #include "ExternalProperty.h"
 
 #include "rulesets/Character.h"
@@ -36,8 +36,9 @@
 #include "common/Update.h"
 #include "common/globals.h"
 #include "common/serialno.h"
-#include "common/inheritance.h"
+#include "common/Inheritance.h"
 #include "common/system.h"
+#include "common/TypeNode.h"
 #include "common/compose.hpp"
 
 #include <Atlas/Objects/Operation.h>
@@ -61,7 +62,7 @@ Connection::Connection(CommClient & client,
                        ServerRouting & svr,
                        const std::string & addr,
                        const std::string & id) :
-            Identified(id, forceIntegerId(id)), m_obsolete(false),
+            Router(id, forceIntegerId(id)), m_obsolete(false),
                                                 m_commClient(client),
                                                 m_server(svr)
 {
@@ -119,8 +120,7 @@ Account * Connection::addPlayer(const std::string& username,
 ///
 /// The object being removed may be a player, or another type of object such
 /// as an avatar. If it is an player or other account, a pointer is returned.
-Account * Connection::removePlayer(IdentifiedRouter * obj,
-                                   const std::string & event)
+Account * Connection::removePlayer(Router * obj, const std::string & event)
 {
     Account * ac = dynamic_cast<Account *>(obj);
     if (ac != 0) {
@@ -130,32 +130,44 @@ Account * Connection::removePlayer(IdentifiedRouter * obj,
                                          ac->getId(), ac->m_username, event));
         return ac;
     }
-    Character * character = dynamic_cast<Character *>(obj);
-    if (character != 0) {
-        if (character->m_externalMind != 0) {
-            // Send a move op stopping the current movement
-            Anonymous move_arg;
-            move_arg->setId(character->getId());
-            // Include the EXTERNAL property which is changing to zero.
-            // It would be more correct at this point to send a separate
-            // update to have the property update itself, but this
-            // will be much less of an issue once Sight(Set) is created
-            // more correctly
-            move_arg->setAttr("external", 0);
-            ::addToEntity(Vector3D(0,0,0), move_arg->modifyVelocity());
+    Character * chr = dynamic_cast<Character *>(obj);
+    if (chr != 0) {
+        if (chr->m_externalMind != 0) {
+            ExternalMind * mind = dynamic_cast<ExternalMind*>(chr->m_externalMind);
+            if (mind != 0 && mind->isConnectedTo(this)) {
+                // Send a move op stopping the current movement
+                Anonymous move_arg;
+                move_arg->setId(chr->getId());
+                // Include the EXTERNAL property which is changing to zero.
+                // It would be more correct at this point to send a separate
+                // update to have the property update itself, but this
+                // will be much less of an issue once Sight(Set) is created
+                // more correctly
+                move_arg->setAttr("external", 0);
+                ::addToEntity(Vector3D(0,0,0), move_arg->modifyVelocity());
 
-            Move move;
-            move->setFrom(character->getId());
-            move->setArgs1(move_arg);
-            character->externalOperation(move);
+                Move move;
+                move->setFrom(chr->getId());
+                move->setArgs1(move_arg);
+                chr->externalOperation(move);
 
-            delete character->m_externalMind;
-            character->m_externalMind = 0;
-            logEvent(DROP_CHAR, String::compose("%1 - %2 %4 character (%3)",
-                                                getId(),
-                                                character->getId(),
-                                                character->getType(),
-                                                event));
+                // We used to delete the external mind here, but now we
+                // leave it in place, as it takes care of the disconnected
+                // character.
+                mind->connect(0);
+                logEvent(DROP_CHAR, String::compose("%1 - %2 %4 character (%3)",
+                                                    getId(), chr->getId(),
+                                                    chr->getType()->name(),
+                                                    event));
+            } else if (mind != 0 && mind->isConnected()) {
+                log(ERROR, String::compose("Connection(%1) requested to "
+                                           "remove active character %2(%3) "
+                                           "which is subscribed to another "
+                                           "Connection(%4).", getId(),
+                                           chr->getType()->name(),
+                                           chr->getId(),
+                                           mind->connectionId()));
+            }
         }
     }
     return 0;
@@ -169,7 +181,7 @@ void Connection::addEntity(Entity * ent)
                                       ent->getIntId()));
 }
 
-void Connection::addObject(IdentifiedRouter * obj)
+void Connection::addObject(Router * obj)
 {
     m_objects[obj->getIntId()] = obj;
 }
@@ -193,11 +205,23 @@ void Connection::disconnect()
 
 void Connection::connectAvatar(Character * chr)
 {
-    chr->m_externalMind = new ExternalMind(*this, chr->getId(),
-                                                  chr->getIntId());
+    ExternalMind * mind = 0;
+    if (chr->m_externalMind != 0) {
+        mind = dynamic_cast<ExternalMind*>(chr->m_externalMind);
+    }
+    if (mind == 0) {
+        chr->m_externalMind = mind = new ExternalMind(*chr);
+    }
+
+    if (mind->isConnected()) {
+        log(ERROR, "Character is already connected.");
+        return;
+    }
+    mind->connect(this);
 
     if (chr->getProperty("external") == 0) {
         ExternalProperty * ep = new ExternalProperty(chr->m_externalMind);
+        // FIXME ensure this is install()ed and apply()ed
         chr->setProperty("external", ep);
     }
 
@@ -261,27 +285,33 @@ void Connection::operation(const Operation & op, OpVector & res)
               res);
         return;
     }
-    IdentifiedRouter * obj = I->second;
+    Router * obj = I->second;
     Entity * ig_ent = dynamic_cast<Entity *>(obj);
     if (ig_ent == NULL) {
         obj->operation(op, res);
         return;
     }
-    Character * character = dynamic_cast<Character *>(obj);
-    if (character != NULL && character->m_externalMind == NULL) {
-        debug(std::cout << "Subscribing existing character" << std::endl
-                        << std::flush;);
-        connectAvatar(character);
-        Info info;
-        Anonymous info_arg;
-        character->addToEntity(info_arg);
-        info->setArgs1(info_arg);
+    Character * chr = dynamic_cast<Character *>(obj);
+    if (chr != NULL) {
+        ExternalMind * mind = 0;
+        if (chr->m_externalMind != 0) {
+            mind = dynamic_cast<ExternalMind*>(chr->m_externalMind);
+        }
+        if (mind == 0 || !mind->isConnected()) {
+            debug(std::cout << "Subscribing existing character" << std::endl
+                            << std::flush;);
+            connectAvatar(chr);
+            Info info;
+            Anonymous info_arg;
+            chr->addToEntity(info_arg);
+            info->setArgs1(info_arg);
 
-        res.push_back(info);
+            res.push_back(info);
 
-        logEvent(TAKE_CHAR, String::compose("%1 - %2 Taken character (%3)",
-                                            getId(), ig_ent->getId(),
-                                            ig_ent->getType()));
+            logEvent(TAKE_CHAR, String::compose("%1 - %2 Taken character (%3)",
+                                                getId(), ig_ent->getId(),
+                                                ig_ent->getType()));
+        }
     }
     ig_ent->externalOperation(op);
 }
@@ -323,9 +353,9 @@ void Connection::LoginOperation(const Operation & op, OpVector & res)
         debug(std::cout << "No account called " << username
                         << " in server. Checking in database."
                         << std::endl << std::flush;);
-        player = Persistance::instance()->getAccount(username);
+        player = Persistence::instance()->getAccount(username);
         if (player != 0) {
-            Persistance::instance()->registerCharacters(*player,
+            Persistence::instance()->registerCharacters(*player,
                                                m_server.m_world.getEntities());
             m_server.addAccount(player);
         }
@@ -402,7 +432,7 @@ void Connection::CreateOperation(const Operation & op, OpVector & res)
 
     if (username.empty() || password.empty() ||
         (0 != m_server.getAccountByName(username)) ||
-        (database_flag && Persistance::instance()->findAccount(username))) {
+        (database_flag && Persistence::instance()->findAccount(username))) {
         // Account exists, or creation data is duff
         clientError(op, "Account creation is invalid", res);
         return;
@@ -413,7 +443,7 @@ void Connection::CreateOperation(const Operation & op, OpVector & res)
         return;
     }
     if (database_flag) {
-        Persistance::instance()->putAccount(*player);
+        Persistence::instance()->putAccount(*player);
     }
     Info info;
     Anonymous info_arg;
@@ -476,22 +506,29 @@ void Connection::LogoutOperation(const Operation & op, OpVector & res)
                                                    chr->getType(),
                                                    chr->getId()));
                     } else {
-                        if (&em->m_connection != this) {
+                        if (!em->isConnected()) {
+                            log(ERROR,
+                                String::compose("Connection(%1) has found a "
+                                                "character in its dictionery "
+                                                "which is not connected.",
+                                                getId()));
+                            removeObject(chr->getIntId());
+                        } else if (!em->isConnectedTo(this)) {
                             log(ERROR,
                                 String::compose("Connection(%1) has found a "
                                                 "character in its dictionery "
                                                 "which is connected to another "
                                                 "Connection(%2)", getId(),
-                                                em->m_connection.getId()));
-                            removeObject(J->second->getIntId());
+                                                em->connectionId()));
+                            removeObject(chr->getIntId());
                         }
                     }
                 } else {
-                    removeObject(J->second->getIntId());
+                    removeObject(chr->getIntId());
                 }
             } else {
                 // Non character entity
-                removeObject(J->second->getIntId());
+                removeObject(chr->getIntId());
             }
         }
     }
