@@ -15,20 +15,27 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 1907487fccdebd5c35f8d22e70d24c467ca4fb7d $
 
 #ifndef SERVER_ENTITY_FACTORY_H
 #define SERVER_ENTITY_FACTORY_H
 
-#include <Atlas/Message/Element.h>
-
 #include <set>
+#include <map>
+#include <string>
+
+namespace Atlas {
+    namespace Message {
+        class Element;
+        typedef std::map<std::string, Element> MapType;
+    }
+}
 
 class Entity;
-class ScriptFactory;
+class ScriptKit;
 class TypeNode;
 
-/// \brief Base class for for factories for creating entities
+/// \brief Abstract factory for creating in-game entity objects.
 ///
 /// An Entity consists of an instance of one of a number of C++ classes
 /// optionally with a script. Stores information about default attributes,
@@ -37,7 +44,7 @@ class EntityKit {
   protected:
     EntityKit();
   public:
-    ScriptFactory * m_scriptFactory;
+    ScriptKit * m_scriptFactory;
     /// Default attribute values for this class
     Atlas::Message::MapType m_classAttributes;
     /// Default attribute values for instances of this class, including
@@ -69,6 +76,7 @@ class EntityKit {
     virtual EntityKit * duplicateFactory() = 0;
 };
 
+/// \brief Concrete factory template for creating in-game entity objects.
 template <class T>
 class EntityFactory : public EntityKit {
   protected:
