@@ -15,12 +15,12 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Master.h,v 1.6 2008-01-28 23:48:33 alriddoch Exp $
+// $Id$
 
 #ifndef SERVER_MASTER_H
 #define SERVER_MASTER_H
 
-#include "common/Identified.h"
+#include "common/Router.h"
 
 class CommClient;
 class ServerRouting;
@@ -29,7 +29,7 @@ class ServerRouting;
 /// program is a slave.
 ///
 /// This is designed to be used from a cyphesis process running as an AI slave.
-class Master : public IdentifiedRouter {
+class Master : public Router {
   protected:
     
   public:
@@ -38,6 +38,8 @@ class Master : public IdentifiedRouter {
 
     Master(CommClient & client, ServerRouting & svr, const std::string & id);
     virtual ~Master();
+
+    virtual void operation(const Operation &, OpVector &);
 };
 
 #endif // SERVER_MASTER_H
