@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Peer.cpp,v 1.10 2008-01-28 23:48:33 alriddoch Exp $
+// $Id$
 
 #include "Peer.h"
 
@@ -31,7 +31,7 @@ Peer::Peer(CommClient & client,
            ServerRouting & svr,
            const std::string & addr,
            const std::string & id) :
-      Identified(id, forceIntegerId(id)), m_commClient(client), m_server(svr)
+      Router(id, forceIntegerId(id)), m_commClient(client), m_server(svr)
 {
 }
 
