@@ -15,7 +15,9 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 48f644f400f7d7bbceb675857f8801e0a5da3bed $
+
+#include <Python.h>
 
 #include "ScriptFactory.h"
 
@@ -28,17 +30,17 @@
 #include "common/log.h"
 #include "common/compose.hpp"
 
-/// \brief ScriptFactory constructor
+/// \brief ScriptKit constructor
 /// 
 /// @param package name of the script package scripts are to be created from
 /// @param type name of the type instanced to create scripts
-ScriptFactory::ScriptFactory(const std::string & package,
-                             const std::string & type) : m_package(package),
-                                                         m_type(type)
+ScriptKit::ScriptKit(const std::string & package,
+                     const std::string & type) : m_package(package),
+                                                 m_type(type)
 {
 }
 
-ScriptFactory::~ScriptFactory()
+ScriptKit::~ScriptKit()
 {
 }
 
@@ -46,20 +48,20 @@ ScriptFactory::~ScriptFactory()
 /// already been loaded.
 int PythonScriptFactory::getClass()
 {
-    m_class = PyObject_GetAttrString(m_module, (char *)m_type.c_str());
-    if (m_class == NULL) {
-        log(ERROR, String::compose("Could not find python class %1.%2",
-                                   m_package, m_type));
-        PyErr_Print();
+    m_class = Get_PyClass(m_module, m_package, m_type);
+    if (m_class == 0) {
         return -1;
     }
-    if (PyCallable_Check(m_class) == 0) {
-        log(ERROR, String::compose("Could not instance python class %1.%2",
+    if (!PyType_IsSubtype((PyTypeObject*)m_class, &PyEntity_Type) &&
+        !PyType_IsSubtype((PyTypeObject*)m_class, &PyCharacter_Type)) {
+        log(ERROR, String::compose("Python class does not inherit from "
+                                   "a core server type. \"%1.%2\"",
                                    m_package, m_type));
         Py_DECREF(m_class);
         m_class = 0;
         return -1;
     }
+
     return 0;
 }
 
@@ -69,16 +71,12 @@ int PythonScriptFactory::getClass()
 /// @param type Name of the scrpt types instanced by this factory
 PythonScriptFactory::PythonScriptFactory(const std::string & package,
                                          const std::string & type) :
-                                         ScriptFactory(package, type),
+                                         ScriptKit(package, type),
                                          m_module(0), m_class(0)
 {
     // FIXME #4 This sort of code should not be in the constructor
-    PyObject * package_name = PyString_FromString((char *)m_package.c_str());
-    m_module = PyImport_Import(package_name);
-    Py_DECREF(package_name);
+    m_module = Get_PyModule(m_package);
     if (m_module == NULL) {
-        log(ERROR, String::compose("Missing python module \"%1\"", m_package));
-        PyErr_Print();
         return;
     }
     getClass();
@@ -100,16 +98,19 @@ int PythonScriptFactory::addScript(Entity * entity)
         return -1;
     }
     PyEntity * wrapper = newPyEntity();
-    wrapper->m_entity = entity;
+    wrapper->m_entity.e = entity;
+
     PyObject * script = Create_PyScript((PyObject *)wrapper, m_class);
 
-    if (script == NULL) {
-        return -1;
+    Py_DECREF(wrapper);
+
+    if (script != NULL) {
+        entity->setScript(new PythonEntityScript(script));
+
+        Py_DECREF(script);
     }
 
-    entity->setScript(new PythonEntityScript(script, (PyObject *)wrapper));
-
-    return 0;
+    return (script == NULL) ? -1 : 0;
 }
 
 int PythonScriptFactory::refreshClass()
