@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: SlaveClientConnection.cpp,v 1.7 2008-01-28 23:48:33 alriddoch Exp $
+// $Id$
 
 #include "SlaveClientConnection.h"
 
@@ -24,13 +24,19 @@
 /// @param id identifier of the connection
 /// @param client network object the client is connected to
 /// @param svr core server object
-SlaveClientConnection::SlaveClientConnection(const std::string & id,
-                                             CommClient & client,
-                                             ServerRouting & svr) :
-                       Identified(id, -1), m_commClient(client), m_server(svr)
+SlaveClientConnection::SlaveClientConnection(CommClient & client,
+                                             ServerRouting & svr,
+                                             const std::string & address,
+                                             const std::string & id) :
+                       Router(id, -1),
+                       m_commClient(client), m_server(svr)
 {
 }
 
 SlaveClientConnection::~SlaveClientConnection()
 {
 }
+
+void SlaveClientConnection::operation(const Operation &, OpVector &)
+{
+}
