@@ -15,13 +15,14 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 9822d2fdd2f4abf2e0abd59ba89625f7cdeeaad7 $
 
 #include "WorldRouter.h"
 
 #include "EntityBuilder.h"
 
 #include "rulesets/World.h"
+#include "rulesets/Domain.h"
 
 #include "common/id.h"
 #include "common/log.h"
@@ -35,6 +36,7 @@
 #include "common/compose.hpp"
 #include "common/Inheritance.h"
 #include "common/Monitors.h"
+#include "common/Variable.h"
 
 #include <Atlas/Objects/Operation.h>
 #include <Atlas/Objects/Anonymous.h>
@@ -115,7 +117,7 @@ WorldRouter::WorldRouter() : BaseWorld(*new World(consts::rootWorldId,
     m_eobjects[m_gameWorld.getIntId()] = &m_gameWorld;
     m_perceptives.insert(&m_gameWorld);
     //WorldTime tmp_date("612-1-1 08:57:00");
-    Monitors::instance()->watch("entities", new Monitor<int>(m_entityCount));
+    Monitors::instance()->watch("entities", new Variable<int>(m_entityCount));
 }
 
 /// \brief Destructor for the world object.
@@ -184,55 +186,6 @@ Operation WorldRouter::getOperationFromQueue()
     return op;
 }
 
-/// \brief Provide an adjusted height for the given entity.
-///
-/// If the position has a parent which has an associated geometry
-/// which define its childrens position, e.g terrain or a floor,
-/// calculate what the Z coord, being the height of the entity.
-/// This function recurses through the parents until it finds
-/// A parent which defines the height.
-/// @return the modified Z coord of the position.
-float WorldRouter::constrainHeight(LocatedEntity * parent,
-                                   const Point3D & pos,
-                                   const std::string & mode)
-{
-    assert(parent != 0);
-    World * wrld = dynamic_cast<World*>(parent);
-    if (wrld != 0) {
-        float h;
-        h = wrld->getHeight(pos.x(), pos.y());
-        if (mode == "fixed") {
-            h = pos.z();
-        } else if (mode == "floating") {
-            h = 0;
-        } else if (mode == "swimming") {
-            h = std::max(h, std::min(0.f, pos.z()));
-        } else if (mode == "relative") {
-            h = h + pos.z();
-        }
-        debug(std::cout << "Fix height " << pos.z() << " to " << h
-                        << std::endl << std::flush;);
-        return h;
-    } else {
-        static const Quaternion identity(Quaternion().identity());
-        assert(parent->m_location.m_loc != 0);
-        const Point3D & ppos = parent->m_location.pos();
-        debug(std::cout << "parent " << parent->getId() << " of type "
-                        << parent->getType() << " pos " << ppos.z()
-                        << " my pos " << pos.z()
-                        << std::endl << std::flush;);
-        float h;
-        const Quaternion & parent_orientation = parent->m_location.orientation().isValid() ? parent->m_location.orientation() : identity;
-        h =  constrainHeight(parent->m_location.m_loc,
-                             pos.toParentCoords(parent->m_location.pos(),
-                                                parent_orientation),
-                             mode) - ppos.z();
-        debug(std::cout << "Correcting height from " << pos.z() << " to " << h
-                        << std::endl << std::flush;);
-        return h;
-    }
-}
-
 /// \brief Add a new entity to the world.
 ///
 /// Adds a new entity to the lists maintained by the WorldRouter.
@@ -261,22 +214,14 @@ Entity * WorldRouter::addEntity(Entity * ent)
     ent->m_location.update(getTime());
     // FIXME
     std::string mode;
-    if (ent->hasAttr("mode")) {
-        Element mode_attr;
-        ent->getAttr("mode", mode_attr);
-        if (mode_attr.isString()) {
-            mode = mode_attr.String();
-            if (mode == "relative") {
-                ent->setAttr("mode", "fixed");
-            }
-        } else {
-            log(ERROR, String::compose("Mode on entity is a %1 in "
-                                       "WorldRouter::addEntity",
-                                       Element::typeName(mode_attr.getType())));
-        }
+    Element mode_attr;
+    if (ent->getAttrType("mode", mode_attr, Element::TYPE_STRING)) {
+        mode = mode_attr.String();
     }
-    ent->m_location.m_pos.z() = constrainHeight(ent->m_location.m_loc,
-                                                ent->m_location.pos(), mode);
+    ent->m_location.m_pos.z() = ent->getMovementDomain()->
+          constrainHeight(ent->m_location.m_loc,
+                          ent->m_location.pos(),
+                          mode);
     ent->m_location.m_loc->makeContainer();
     bool cont_change = ent->m_location.m_loc->m_contains->empty();
     ent->m_location.m_loc->m_contains->insert(ent);
