@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: edad7c5caef63f5190f57da418a3c0c2e57c2217 $
 
 #include "PropertyExerciser.h"
 
@@ -75,7 +75,7 @@ int main()
     }
 
     {
-        AreaProperty test_property(0);
+        AreaProperty test_property;
         assert(exerciser.exerciseProperty(test_property, TYPE_MAP) == 0);
     }
 
@@ -108,7 +108,7 @@ int main()
     }
 
     {
-        CalendarProperty test_property(0);
+        CalendarProperty test_property;
         assert(exerciser.exerciseProperty(test_property, TYPE_MAP) == 0);
     }
 
@@ -145,11 +145,7 @@ int main()
     }
 
     {
-        Mercator::Terrain test_terrain_data;
-        PointSet test_pointset_data1, test_pointset_data2;
-        TerrainProperty test_property(test_terrain_data,
-                                      test_pointset_data1,
-                                      test_pointset_data2, 0);
+        TerrainProperty test_property;
         assert(exerciser.exerciseProperty(test_property, TYPE_MAP) == 0);
     }
 
