@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 204df8c73d0129d9134509440cc7bbe649ec807c $
 
 #include "PropertyCoverage.h"
 
@@ -23,7 +23,7 @@
 
 int main()
 {
-    CalendarProperty * ap = new CalendarProperty(0);
+    CalendarProperty * ap = new CalendarProperty;
 
     PropertyCoverage pc(ap);
 
