@@ -15,12 +15,15 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: EntityExerciser.h,v 1.28 2008-01-17 19:53:39 alriddoch Exp $
+// $Id$
 
 #ifndef TESTS_ENTITY_EXERCISER_H
 #define TESTS_ENTITY_EXERCISER_H
 
+#include "rulesets/LocatedEntity.h"
+
 #include "common/OperationRouter.h"
+#include "common/TypeNode.h"
 
 #include "common/Add.h"
 #include "common/Burn.h"
@@ -44,10 +47,36 @@ template <class EntityType>
 class EntityExerciser {
   protected:
     EntityType & m_ent;
+    std::set<int> attr_types;
   public:
-    explicit EntityExerciser(EntityType & e) : m_ent(e) { }
+    explicit EntityExerciser(EntityType & e) : m_ent(e) {
+        if (e.getIntId() == 0) {
+            e.makeContainer();
+            assert(e.m_contains != 0);
+        } else {
+            e.m_location.m_loc = new EntityType("0", 0);
+            e.m_location.m_loc->makeContainer();
+            assert(e.m_location.m_loc->m_contains != 0);
+            e.m_location.m_loc->m_contains->insert(&e);
+        }
+        if (e.getType() == 0) {
+            TypeNode * test_type = new TypeNode;
+            test_type->name() = "test_type";
+            e.setType(test_type);
+        }
+        attr_types.insert(Atlas::Message::Element::TYPE_INT);
+        attr_types.insert(Atlas::Message::Element::TYPE_FLOAT);
+        attr_types.insert(Atlas::Message::Element::TYPE_STRING);
+        attr_types.insert(Atlas::Message::Element::TYPE_MAP);
+        attr_types.insert(Atlas::Message::Element::TYPE_LIST);
+    }
     virtual ~EntityExerciser() { }
 
+    bool checkAttributes(const std::set<std::string> & attr_names);
+    bool checkProperties(const std::set<std::string> & prop_names);
+
+    bool fullAttributeTest(const Atlas::Message::MapType & attr_data);
+
     virtual void dispatchOp(const Atlas::Objects::Operation::RootOperation&op) {
         OpVector ov1;
         m_ent.operation(op, ov1);
@@ -56,11 +85,48 @@ class EntityExerciser {
 
     void addAllOperations(std::set<std::string> & ops);
 
-    void runOperations();
+    virtual void runOperations();
     void runConversions();
     void flushOperations(OpVector & ops);
 };
 
+template <class EntityType>
+inline bool EntityExerciser<EntityType>::checkAttributes(const std::set<std::string> & attr_names)
+{
+    Atlas::Message::Element null;
+    bool res = true;
+    std::set<std::string>::const_iterator I = attr_names.begin();
+    std::set<std::string>::const_iterator Iend = attr_names.end();
+    for (; I != Iend; ++I) {
+        if (!this->m_ent.getAttr(*I, null)) {
+            std::cerr << "Entity does not have \"" << *I << "\" attribute."
+                      << std::endl << std::flush;
+            res = false;
+        }
+        if (this->m_ent.getProperty(*I) == NULL) {
+            std::cerr << "Entity does not have \"" << *I << "\" property."
+                      << std::endl << std::flush;
+            res = false;
+        }
+        std::set<int>::const_iterator J = attr_types.begin();
+        std::set<int>::const_iterator Jend = attr_types.end();
+        for (; J != Jend; ++J) {
+            this->m_ent.getAttrType(*I, null, *J);
+        }
+    }
+    return res;
+}
+
+template <class EntityType>
+inline bool EntityExerciser<EntityType>::checkProperties(const std::set<std::string> & prop_names)
+{
+    std::set<std::string>::const_iterator I = prop_names.begin();
+    std::set<std::string>::const_iterator Iend = prop_names.end();
+    for (; I != Iend; ++I) {
+    }
+    return true;
+}
+
 template <class EntityType>
 inline void EntityExerciser<EntityType>::addAllOperations(std::set<std::string> & ops)
 {
