@@ -15,9 +15,10 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 2f5ebae4a8212702e4e6a486a8f003607f368718 $
 
 #include "common/Monitors.h"
+#include "common/Variable.h"
 
 #include <iostream>
 
@@ -31,7 +32,7 @@ int main()
 
     int foo = 1;
 
-    m->watch("foo", new Monitor<int>(foo));
+    m->watch("foo", new Variable<int>(foo));
 
     m->insert("bar", 3);
     m->insert("mim", 3.f);
