@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 041ce4ff2689926656c0a4eeceb931d0e83e9eb1 $
 
 #ifndef TESTS_PROPERTY_COVERAGE_H
 #define TESTS_PROPERTY_COVERAGE_H
@@ -25,13 +25,14 @@
 class PropertyBase;
 class Entity;
 class BaseWorld;
+class Character;
 
 class PropertyCoverage {
   protected:
     PropertyBase * const prop;
     Entity * const tlve;
     BaseWorld * const wrld;
-    Entity * const ent;
+    Entity * ent;
 
     Atlas::Message::ListType m_testData;
   public:
@@ -42,6 +43,8 @@ class PropertyCoverage {
 
     void basicCoverage();
 
+    Character * createCharacterEntity();
+
     void testDataAppend(const Atlas::Message::Element &);
 };
 
