@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Stackabletest.cpp,v 1.14 2008-01-07 14:35:49 alriddoch Exp $
+// $Id$
 
 #include "IGEntityExerciser.h"
 #include "allOperations.h"
@@ -50,8 +50,6 @@ int main()
 
     std::set<std::string> attrNames;
     attrNames.insert("id");
-    attrNames.insert("bbox");
-    attrNames.insert("num");
 
     // Make sure we have all the default attributes
     assert(ee.checkAttributes(attrNames));
@@ -92,7 +90,7 @@ int main()
     e.addToMessage(entityAsAtlas);
 
     // Make sure we got at least some of it
-    assert(entityAsAtlas.size() > 14);
+    assert(entityAsAtlas.size() > 13);
 
     // Read the contents of the Atlas Message back in
     e.merge(entityAsAtlas);
