@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id$
+// $Id: 6c8de66b7fc35d230de251fe8cf0c2f269dcfd7d $
 
 #include "PropertyCoverage.h"
 
@@ -26,10 +26,8 @@
 int main()
 {
     Mercator::Terrain terrain;
-    PointSet modifiedTerrain;
-    PointSet createdTerrain;
 
-    TerrainProperty * ap = new TerrainProperty(terrain, modifiedTerrain, createdTerrain, 0);
+    TerrainProperty * ap = new TerrainProperty;
 
     PropertyCoverage pc(ap);
 
